# Proc to create Block Design
proc create_block_design { parentCell design_name target_path } {

    # Define design name
    set block_design_name $design_name
    write_msg "INFO: Creating block design $block_design_name" "1"
    create_bd_design $block_design_name

    # Hierarchical cell: link_7
    proc create_hier_cell_link_7 { parentCell nameHier } {

        variable script_folder

        if { $parentCell eq "" || $nameHier eq "" } {
            catch {common::send_msg_id "BD_TCL-102" "ERROR" "create_hier_cell_link_7() - Empty argument(s)!"}
            return
        }

        # Get object for parentCell
        set parentObj [get_bd_cells $parentCell]
        if { $parentObj == "" } {
            catch {common::send_msg_id "BD_TCL-100" "ERROR" "Unable to find parent cell <$parentCell>!"}
            return
        }

        # Make sure parentObj is hier blk
        set parentType [get_property TYPE $parentObj]
        if { $parentType ne "hier" } {
            catch {common::send_msg_id "BD_TCL-101" "ERROR" "Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."}
            return
        }

        # Save current instance; Restore later
        set oldCurInst [current_bd_instance .]

        # Set parent object as current
        current_bd_instance $parentObj

        # Create cell and set as current instance
        set hier_obj [create_bd_cell -type hier $nameHier]
        current_bd_instance $hier_obj

        # Create interface pins
        create_bd_intf_pin -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 GT_RX

        create_bd_intf_pin -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 GT_TX

        create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 s_axi


        # Create pins
        create_bd_pin -dir I -type clk aurora_init_clk
        create_bd_pin -dir O axi_c2c_config_error
        create_bd_pin -dir O axi_c2c_link_error
        create_bd_pin -dir O axi_c2c_link_status
        create_bd_pin -dir O axi_c2c_multi_bit_error
        create_bd_pin -dir O channel_up
        create_bd_pin -dir O gt_pll_lock
        create_bd_pin -dir I gt_refclk
        create_bd_pin -dir O hard_err
        create_bd_pin -dir I reset
        create_bd_pin -dir I -type clk s_aclk
        create_bd_pin -dir I -type rst s_aresetn

        # Create instance: aurora, and set properties
        set aurora [ create_bd_cell -type ip -vlnv xilinx.com:ip:aurora_8b10b aurora ]
        set_property -dict [ list \
            CONFIG.CHANNEL_ENABLE {X0Y8} \
            CONFIG.C_DRP_IF {true} \
            CONFIG.C_LANE_WIDTH {4} \
            CONFIG.C_LINE_RATE {6.25} \
            CONFIG.C_REFCLK_FREQUENCY {125} \
            CONFIG.C_REFCLK_SOURCE {MGTREFCLK0 of Quad X0Y2} \
            CONFIG.C_START_LANE {X0Y8} \
            CONFIG.C_START_QUAD {Quad_X0Y2} \
            CONFIG.Interface_Mode {Streaming} \
            ] $aurora

        # Create instance: axi_c2c, and set properties
        set axi_c2c [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_chip2chip axi_c2c ]
        set_property -dict [ list \
            CONFIG.C_AURORA_WIDTH {1} \
            CONFIG.C_ECC_ENABLE {false} \
            CONFIG.C_EN_AXI_LINK_HNDLR {true} \
            CONFIG.C_INTERFACE_MODE {1} \
            CONFIG.C_INTERFACE_TYPE {3} \
            ] $axi_c2c

        # Create instance: buf_gt, and set properties
        set buf_gt [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_ds_buf buf_gt ]
        set_property -dict [ list \
            CONFIG.C_BUF_TYPE {BUFG_GT} \
            ] $buf_gt

        # Create instance: const_0, and set properties
        set const_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_0 ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            ] $const_0

        # Create instance: const_1, and set properties
        set const_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_1 ]

        # Create instance: const_drpaddr, and set properties
        set const_drpaddr [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_drpaddr ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {10} \
            ] $const_drpaddr

        # Create instance: const_drpdi, and set properties
        set const_drpdi [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_drpdi ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {16} \
            ] $const_drpdi

        # Create instance: const_gt_div, and set properties
        set const_gt_div [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_gt_div ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {3} \
            ] $const_gt_div

        # Create interface connections
        connect_bd_intf_net -intf_net GT_RX_1 [get_bd_intf_pins GT_RX] [get_bd_intf_pins aurora/GT_SERIAL_RX]
        connect_bd_intf_net -intf_net aurora_GT_SERIAL_TX [get_bd_intf_pins GT_TX] [get_bd_intf_pins aurora/GT_SERIAL_TX]
        connect_bd_intf_net -intf_net aurora_USER_DATA_M_AXI_RX [get_bd_intf_pins aurora/USER_DATA_M_AXI_RX] [get_bd_intf_pins axi_c2c/AXIS_RX]
        connect_bd_intf_net -intf_net axi_c2c_AXIS_TX [get_bd_intf_pins aurora/USER_DATA_S_AXI_TX] [get_bd_intf_pins axi_c2c/AXIS_TX]
        connect_bd_intf_net -intf_net axi_c2c_xbar_0_M00_AXI [get_bd_intf_pins s_axi] [get_bd_intf_pins axi_c2c/s_axi]

        # Create port connections
        connect_bd_net -net aclk_0_1 [get_bd_pins s_aclk] [get_bd_pins axi_c2c/s_aclk]
        connect_bd_net -net aresetn_0_1 [get_bd_pins s_aresetn] [get_bd_pins axi_c2c/s_aresetn]
        connect_bd_net -net aurora_64b66b_channel_up [get_bd_pins channel_up] [get_bd_pins aurora/channel_up] [get_bd_pins axi_c2c/axi_c2c_aurora_channel_up]
        connect_bd_net -net aurora_bufg_gt_clr_out [get_bd_pins aurora/bufg_gt_clr_out] [get_bd_pins axi_c2c/aurora_mmcm_not_locked] [get_bd_pins buf_gt/BUFG_GT_CLR]
        connect_bd_net -net aurora_hard_err [get_bd_pins hard_err] [get_bd_pins aurora/hard_err]
        connect_bd_net -net aurora_init_clk_0_1 [get_bd_pins aurora_init_clk] [get_bd_pins aurora/init_clk_in] [get_bd_pins axi_c2c/aurora_init_clk]
        connect_bd_net -net aurora_tx_lock [get_bd_pins gt_pll_lock] [get_bd_pins aurora/tx_lock]
        connect_bd_net -net aurora_tx_out_clk [get_bd_pins aurora/tx_out_clk] [get_bd_pins buf_gt/BUFG_GT_I]
        connect_bd_net -net axi_c2c_aurora_pma_init_out [get_bd_pins aurora/gt_reset] [get_bd_pins axi_c2c/aurora_pma_init_out]
        connect_bd_net -net axi_c2c_aurora_reset_pb [get_bd_pins aurora/reset] [get_bd_pins axi_c2c/aurora_reset_pb]
        connect_bd_net -net axi_c2c_axi_c2c_config_error_out [get_bd_pins axi_c2c_config_error] [get_bd_pins axi_c2c/axi_c2c_config_error_out]
        connect_bd_net -net axi_c2c_axi_c2c_link_error_out [get_bd_pins axi_c2c_link_error] [get_bd_pins axi_c2c/axi_c2c_link_error_out]
        connect_bd_net -net axi_c2c_axi_c2c_link_status_out [get_bd_pins axi_c2c_link_status] [get_bd_pins axi_c2c/axi_c2c_link_status_out]
        connect_bd_net -net axi_c2c_axi_c2c_multi_bit_error_out [get_bd_pins axi_c2c_multi_bit_error] [get_bd_pins axi_c2c/axi_c2c_multi_bit_error_out]
        connect_bd_net -net buf_gt_BUFG_GT_O [get_bd_pins aurora/sync_clk] [get_bd_pins aurora/user_clk] [get_bd_pins axi_c2c/axi_c2c_phy_clk] [get_bd_pins buf_gt/BUFG_GT_O]
        connect_bd_net -net const_0_dout [get_bd_pins buf_gt/BUFG_GT_DIV] [get_bd_pins const_gt_div/dout]
        connect_bd_net -net const_0_dout1 [get_bd_pins aurora/gt0_drpen] [get_bd_pins aurora/gt0_drpwe] [get_bd_pins buf_gt/BUFG_GT_CEMASK] [get_bd_pins buf_gt/BUFG_GT_CLRMASK] [get_bd_pins const_0/dout]
        connect_bd_net -net const_1_dout [get_bd_pins buf_gt/BUFG_GT_CE] [get_bd_pins const_1/dout]
        connect_bd_net -net const_drpaddr_dout [get_bd_pins aurora/gt0_drpaddr] [get_bd_pins const_drpaddr/dout]
        connect_bd_net -net const_drpdi_dout [get_bd_pins aurora/gt0_drpdi] [get_bd_pins const_drpdi/dout]
        connect_bd_net -net gt_refclk_1 [get_bd_pins gt_refclk] [get_bd_pins aurora/gt_refclk1]
        connect_bd_net -net reset_1 [get_bd_pins reset] [get_bd_pins axi_c2c/aurora_pma_init_in]

        # Restore current instance
        current_bd_instance $oldCurInst
    }

    # Hierarchical cell: link_6
    proc create_hier_cell_link_6 { parentCell nameHier } {

        variable script_folder

        if { $parentCell eq "" || $nameHier eq "" } {
            catch {common::send_msg_id "BD_TCL-102" "ERROR" "create_hier_cell_link_6() - Empty argument(s)!"}
            return
        }

        # Get object for parentCell
        set parentObj [get_bd_cells $parentCell]
        if { $parentObj == "" } {
            catch {common::send_msg_id "BD_TCL-100" "ERROR" "Unable to find parent cell <$parentCell>!"}
            return
        }

        # Make sure parentObj is hier blk
        set parentType [get_property TYPE $parentObj]
        if { $parentType ne "hier" } {
            catch {common::send_msg_id "BD_TCL-101" "ERROR" "Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."}
            return
        }

        # Save current instance; Restore later
        set oldCurInst [current_bd_instance .]

        # Set parent object as current
        current_bd_instance $parentObj

        # Create cell and set as current instance
        set hier_obj [create_bd_cell -type hier $nameHier]
        current_bd_instance $hier_obj

        # Create interface pins
        create_bd_intf_pin -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 GT_RX

        create_bd_intf_pin -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 GT_TX

        create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 s_axi


        # Create pins
        create_bd_pin -dir I -type clk aurora_init_clk
        create_bd_pin -dir O axi_c2c_config_error
        create_bd_pin -dir O axi_c2c_link_error
        create_bd_pin -dir O axi_c2c_link_status
        create_bd_pin -dir O axi_c2c_multi_bit_error
        create_bd_pin -dir O channel_up
        create_bd_pin -dir O gt_pll_lock
        create_bd_pin -dir I gt_refclk
        create_bd_pin -dir O hard_err
        create_bd_pin -dir I reset
        create_bd_pin -dir I -type clk s_aclk
        create_bd_pin -dir I -type rst s_aresetn

        # Create instance: aurora, and set properties
        set aurora [ create_bd_cell -type ip -vlnv xilinx.com:ip:aurora_8b10b aurora ]
        set_property -dict [ list \
            CONFIG.CHANNEL_ENABLE {X0Y9} \
            CONFIG.C_DRP_IF {true} \
            CONFIG.C_LANE_WIDTH {4} \
            CONFIG.C_LINE_RATE {6.25} \
            CONFIG.C_REFCLK_FREQUENCY {125} \
            CONFIG.C_REFCLK_SOURCE {MGTREFCLK0 of Quad X0Y2} \
            CONFIG.C_START_LANE {X0Y9} \
            CONFIG.C_START_QUAD {Quad_X0Y2} \
            CONFIG.Interface_Mode {Streaming} \
            ] $aurora

        # Create instance: axi_c2c, and set properties
        set axi_c2c [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_chip2chip axi_c2c ]
        set_property -dict [ list \
            CONFIG.C_AURORA_WIDTH {1} \
            CONFIG.C_ECC_ENABLE {false} \
            CONFIG.C_EN_AXI_LINK_HNDLR {true} \
            CONFIG.C_INTERFACE_MODE {1} \
            CONFIG.C_INTERFACE_TYPE {3} \
            ] $axi_c2c

        # Create instance: buf_gt, and set properties
        set buf_gt [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_ds_buf buf_gt ]
        set_property -dict [ list \
            CONFIG.C_BUF_TYPE {BUFG_GT} \
            ] $buf_gt

        # Create instance: const_0, and set properties
        set const_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_0 ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            ] $const_0

        # Create instance: const_1, and set properties
        set const_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_1 ]

        # Create instance: const_drpaddr, and set properties
        set const_drpaddr [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_drpaddr ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {10} \
            ] $const_drpaddr

        # Create instance: const_drpdi, and set properties
        set const_drpdi [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_drpdi ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {16} \
            ] $const_drpdi

        # Create instance: const_gt_div, and set properties
        set const_gt_div [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_gt_div ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {3} \
            ] $const_gt_div

        # Create interface connections
        connect_bd_intf_net -intf_net GT_RX_1 [get_bd_intf_pins GT_RX] [get_bd_intf_pins aurora/GT_SERIAL_RX]
        connect_bd_intf_net -intf_net aurora_GT_SERIAL_TX [get_bd_intf_pins GT_TX] [get_bd_intf_pins aurora/GT_SERIAL_TX]
        connect_bd_intf_net -intf_net aurora_USER_DATA_M_AXI_RX [get_bd_intf_pins aurora/USER_DATA_M_AXI_RX] [get_bd_intf_pins axi_c2c/AXIS_RX]
        connect_bd_intf_net -intf_net axi_c2c_AXIS_TX [get_bd_intf_pins aurora/USER_DATA_S_AXI_TX] [get_bd_intf_pins axi_c2c/AXIS_TX]
        connect_bd_intf_net -intf_net axi_c2c_xbar_0_M00_AXI [get_bd_intf_pins s_axi] [get_bd_intf_pins axi_c2c/s_axi]

        # Create port connections
        connect_bd_net -net aclk_0_1 [get_bd_pins s_aclk] [get_bd_pins axi_c2c/s_aclk]
        connect_bd_net -net aresetn_0_1 [get_bd_pins s_aresetn] [get_bd_pins axi_c2c/s_aresetn]
        connect_bd_net -net aurora_64b66b_channel_up [get_bd_pins channel_up] [get_bd_pins aurora/channel_up] [get_bd_pins axi_c2c/axi_c2c_aurora_channel_up]
        connect_bd_net -net aurora_bufg_gt_clr_out [get_bd_pins aurora/bufg_gt_clr_out] [get_bd_pins axi_c2c/aurora_mmcm_not_locked] [get_bd_pins buf_gt/BUFG_GT_CLR]
        connect_bd_net -net aurora_hard_err [get_bd_pins hard_err] [get_bd_pins aurora/hard_err]
        connect_bd_net -net aurora_init_clk_0_1 [get_bd_pins aurora_init_clk] [get_bd_pins aurora/init_clk_in] [get_bd_pins axi_c2c/aurora_init_clk]
        connect_bd_net -net aurora_tx_lock [get_bd_pins gt_pll_lock] [get_bd_pins aurora/tx_lock]
        connect_bd_net -net aurora_tx_out_clk [get_bd_pins aurora/tx_out_clk] [get_bd_pins buf_gt/BUFG_GT_I]
        connect_bd_net -net axi_c2c_aurora_pma_init_out [get_bd_pins aurora/gt_reset] [get_bd_pins axi_c2c/aurora_pma_init_out]
        connect_bd_net -net axi_c2c_aurora_reset_pb [get_bd_pins aurora/reset] [get_bd_pins axi_c2c/aurora_reset_pb]
        connect_bd_net -net axi_c2c_axi_c2c_config_error_out [get_bd_pins axi_c2c_config_error] [get_bd_pins axi_c2c/axi_c2c_config_error_out]
        connect_bd_net -net axi_c2c_axi_c2c_link_error_out [get_bd_pins axi_c2c_link_error] [get_bd_pins axi_c2c/axi_c2c_link_error_out]
        connect_bd_net -net axi_c2c_axi_c2c_link_status_out [get_bd_pins axi_c2c_link_status] [get_bd_pins axi_c2c/axi_c2c_link_status_out]
        connect_bd_net -net axi_c2c_axi_c2c_multi_bit_error_out [get_bd_pins axi_c2c_multi_bit_error] [get_bd_pins axi_c2c/axi_c2c_multi_bit_error_out]
        connect_bd_net -net buf_gt_BUFG_GT_O [get_bd_pins aurora/sync_clk] [get_bd_pins aurora/user_clk] [get_bd_pins axi_c2c/axi_c2c_phy_clk] [get_bd_pins buf_gt/BUFG_GT_O]
        connect_bd_net -net const_0_dout [get_bd_pins buf_gt/BUFG_GT_DIV] [get_bd_pins const_gt_div/dout]
        connect_bd_net -net const_0_dout1 [get_bd_pins aurora/gt0_drpen] [get_bd_pins aurora/gt0_drpwe] [get_bd_pins buf_gt/BUFG_GT_CEMASK] [get_bd_pins buf_gt/BUFG_GT_CLRMASK] [get_bd_pins const_0/dout]
        connect_bd_net -net const_1_dout [get_bd_pins buf_gt/BUFG_GT_CE] [get_bd_pins const_1/dout]
        connect_bd_net -net const_drpaddr_dout [get_bd_pins aurora/gt0_drpaddr] [get_bd_pins const_drpaddr/dout]
        connect_bd_net -net const_drpdi_dout [get_bd_pins aurora/gt0_drpdi] [get_bd_pins const_drpdi/dout]
        connect_bd_net -net gt_refclk_1 [get_bd_pins gt_refclk] [get_bd_pins aurora/gt_refclk1]
        connect_bd_net -net reset_1 [get_bd_pins reset] [get_bd_pins axi_c2c/aurora_pma_init_in]

        # Restore current instance
        current_bd_instance $oldCurInst
    }

    # Hierarchical cell: link_5
    proc create_hier_cell_link_5 { parentCell nameHier } {

        variable script_folder

        if { $parentCell eq "" || $nameHier eq "" } {
            catch {common::send_msg_id "BD_TCL-102" "ERROR" "create_hier_cell_link_5() - Empty argument(s)!"}
            return
        }

        # Get object for parentCell
        set parentObj [get_bd_cells $parentCell]
        if { $parentObj == "" } {
            catch {common::send_msg_id "BD_TCL-100" "ERROR" "Unable to find parent cell <$parentCell>!"}
            return
        }

        # Make sure parentObj is hier blk
        set parentType [get_property TYPE $parentObj]
        if { $parentType ne "hier" } {
            catch {common::send_msg_id "BD_TCL-101" "ERROR" "Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."}
            return
        }

        # Save current instance; Restore later
        set oldCurInst [current_bd_instance .]

        # Set parent object as current
        current_bd_instance $parentObj

        # Create cell and set as current instance
        set hier_obj [create_bd_cell -type hier $nameHier]
        current_bd_instance $hier_obj

        # Create interface pins
        create_bd_intf_pin -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 GT_RX

        create_bd_intf_pin -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 GT_TX

        create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 s_axi


        # Create pins
        create_bd_pin -dir I -type clk aurora_init_clk
        create_bd_pin -dir O axi_c2c_config_error
        create_bd_pin -dir O axi_c2c_link_error
        create_bd_pin -dir O axi_c2c_link_status
        create_bd_pin -dir O axi_c2c_multi_bit_error
        create_bd_pin -dir O channel_up
        create_bd_pin -dir O gt_pll_lock
        create_bd_pin -dir I gt_refclk
        create_bd_pin -dir O hard_err
        create_bd_pin -dir I reset
        create_bd_pin -dir I -type clk s_aclk
        create_bd_pin -dir I -type rst s_aresetn

        # Create instance: aurora, and set properties
        set aurora [ create_bd_cell -type ip -vlnv xilinx.com:ip:aurora_8b10b aurora ]
        set_property -dict [ list \
            CONFIG.CHANNEL_ENABLE {X0Y10} \
            CONFIG.C_DRP_IF {true} \
            CONFIG.C_LANE_WIDTH {4} \
            CONFIG.C_LINE_RATE {6.25} \
            CONFIG.C_REFCLK_FREQUENCY {125} \
            CONFIG.C_REFCLK_SOURCE {MGTREFCLK0 of Quad X0Y2} \
            CONFIG.C_START_LANE {X0Y10} \
            CONFIG.C_START_QUAD {Quad_X0Y2} \
            CONFIG.Interface_Mode {Streaming} \
            ] $aurora

        # Create instance: axi_c2c, and set properties
        set axi_c2c [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_chip2chip axi_c2c ]
        set_property -dict [ list \
            CONFIG.C_AURORA_WIDTH {1} \
            CONFIG.C_ECC_ENABLE {false} \
            CONFIG.C_EN_AXI_LINK_HNDLR {true} \
            CONFIG.C_INTERFACE_MODE {1} \
            CONFIG.C_INTERFACE_TYPE {3} \
            ] $axi_c2c

        # Create instance: buf_gt, and set properties
        set buf_gt [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_ds_buf buf_gt ]
        set_property -dict [ list \
            CONFIG.C_BUF_TYPE {BUFG_GT} \
            ] $buf_gt

        # Create instance: const_0, and set properties
        set const_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_0 ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            ] $const_0

        # Create instance: const_1, and set properties
        set const_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_1 ]

        # Create instance: const_drpaddr, and set properties
        set const_drpaddr [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_drpaddr ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {10} \
            ] $const_drpaddr

        # Create instance: const_drpdi, and set properties
        set const_drpdi [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_drpdi ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {16} \
            ] $const_drpdi

        # Create instance: const_gt_div, and set properties
        set const_gt_div [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_gt_div ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {3} \
            ] $const_gt_div

        # Create interface connections
        connect_bd_intf_net -intf_net GT_RX_1 [get_bd_intf_pins GT_RX] [get_bd_intf_pins aurora/GT_SERIAL_RX]
        connect_bd_intf_net -intf_net aurora_GT_SERIAL_TX [get_bd_intf_pins GT_TX] [get_bd_intf_pins aurora/GT_SERIAL_TX]
        connect_bd_intf_net -intf_net aurora_USER_DATA_M_AXI_RX [get_bd_intf_pins aurora/USER_DATA_M_AXI_RX] [get_bd_intf_pins axi_c2c/AXIS_RX]
        connect_bd_intf_net -intf_net axi_c2c_AXIS_TX [get_bd_intf_pins aurora/USER_DATA_S_AXI_TX] [get_bd_intf_pins axi_c2c/AXIS_TX]
        connect_bd_intf_net -intf_net axi_c2c_xbar_0_M00_AXI [get_bd_intf_pins s_axi] [get_bd_intf_pins axi_c2c/s_axi]

        # Create port connections
        connect_bd_net -net aclk_0_1 [get_bd_pins s_aclk] [get_bd_pins axi_c2c/s_aclk]
        connect_bd_net -net aresetn_0_1 [get_bd_pins s_aresetn] [get_bd_pins axi_c2c/s_aresetn]
        connect_bd_net -net aurora_64b66b_channel_up [get_bd_pins channel_up] [get_bd_pins aurora/channel_up] [get_bd_pins axi_c2c/axi_c2c_aurora_channel_up]
        connect_bd_net -net aurora_bufg_gt_clr_out [get_bd_pins aurora/bufg_gt_clr_out] [get_bd_pins axi_c2c/aurora_mmcm_not_locked] [get_bd_pins buf_gt/BUFG_GT_CLR]
        connect_bd_net -net aurora_hard_err [get_bd_pins hard_err] [get_bd_pins aurora/hard_err]
        connect_bd_net -net aurora_init_clk_0_1 [get_bd_pins aurora_init_clk] [get_bd_pins aurora/init_clk_in] [get_bd_pins axi_c2c/aurora_init_clk]
        connect_bd_net -net aurora_tx_lock [get_bd_pins gt_pll_lock] [get_bd_pins aurora/tx_lock]
        connect_bd_net -net aurora_tx_out_clk [get_bd_pins aurora/tx_out_clk] [get_bd_pins buf_gt/BUFG_GT_I]
        connect_bd_net -net axi_c2c_aurora_pma_init_out [get_bd_pins aurora/gt_reset] [get_bd_pins axi_c2c/aurora_pma_init_out]
        connect_bd_net -net axi_c2c_aurora_reset_pb [get_bd_pins aurora/reset] [get_bd_pins axi_c2c/aurora_reset_pb]
        connect_bd_net -net axi_c2c_axi_c2c_config_error_out [get_bd_pins axi_c2c_config_error] [get_bd_pins axi_c2c/axi_c2c_config_error_out]
        connect_bd_net -net axi_c2c_axi_c2c_link_error_out [get_bd_pins axi_c2c_link_error] [get_bd_pins axi_c2c/axi_c2c_link_error_out]
        connect_bd_net -net axi_c2c_axi_c2c_link_status_out [get_bd_pins axi_c2c_link_status] [get_bd_pins axi_c2c/axi_c2c_link_status_out]
        connect_bd_net -net axi_c2c_axi_c2c_multi_bit_error_out [get_bd_pins axi_c2c_multi_bit_error] [get_bd_pins axi_c2c/axi_c2c_multi_bit_error_out]
        connect_bd_net -net buf_gt_BUFG_GT_O [get_bd_pins aurora/sync_clk] [get_bd_pins aurora/user_clk] [get_bd_pins axi_c2c/axi_c2c_phy_clk] [get_bd_pins buf_gt/BUFG_GT_O]
        connect_bd_net -net const_0_dout [get_bd_pins buf_gt/BUFG_GT_DIV] [get_bd_pins const_gt_div/dout]
        connect_bd_net -net const_0_dout1 [get_bd_pins aurora/gt0_drpen] [get_bd_pins aurora/gt0_drpwe] [get_bd_pins buf_gt/BUFG_GT_CEMASK] [get_bd_pins buf_gt/BUFG_GT_CLRMASK] [get_bd_pins const_0/dout]
        connect_bd_net -net const_1_dout [get_bd_pins buf_gt/BUFG_GT_CE] [get_bd_pins const_1/dout]
        connect_bd_net -net const_drpaddr_dout [get_bd_pins aurora/gt0_drpaddr] [get_bd_pins const_drpaddr/dout]
        connect_bd_net -net const_drpdi_dout [get_bd_pins aurora/gt0_drpdi] [get_bd_pins const_drpdi/dout]
        connect_bd_net -net gt_refclk_1 [get_bd_pins gt_refclk] [get_bd_pins aurora/gt_refclk1]
        connect_bd_net -net reset_1 [get_bd_pins reset] [get_bd_pins axi_c2c/aurora_pma_init_in]

        # Restore current instance
        current_bd_instance $oldCurInst
    }

    # Hierarchical cell: link_4
    proc create_hier_cell_link_4 { parentCell nameHier } {

        variable script_folder

        if { $parentCell eq "" || $nameHier eq "" } {
            catch {common::send_msg_id "BD_TCL-102" "ERROR" "create_hier_cell_link_4() - Empty argument(s)!"}
            return
        }

        # Get object for parentCell
        set parentObj [get_bd_cells $parentCell]
        if { $parentObj == "" } {
            catch {common::send_msg_id "BD_TCL-100" "ERROR" "Unable to find parent cell <$parentCell>!"}
            return
        }

        # Make sure parentObj is hier blk
        set parentType [get_property TYPE $parentObj]
        if { $parentType ne "hier" } {
            catch {common::send_msg_id "BD_TCL-101" "ERROR" "Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."}
            return
        }

        # Save current instance; Restore later
        set oldCurInst [current_bd_instance .]

        # Set parent object as current
        current_bd_instance $parentObj

        # Create cell and set as current instance
        set hier_obj [create_bd_cell -type hier $nameHier]
        current_bd_instance $hier_obj

        # Create interface pins
        create_bd_intf_pin -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 GT_RX

        create_bd_intf_pin -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 GT_TX

        create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 s_axi


        # Create pins
        create_bd_pin -dir I -type clk aurora_init_clk
        create_bd_pin -dir O axi_c2c_config_error
        create_bd_pin -dir O axi_c2c_link_error
        create_bd_pin -dir O axi_c2c_link_status
        create_bd_pin -dir O axi_c2c_multi_bit_error
        create_bd_pin -dir O channel_up
        create_bd_pin -dir O gt_pll_lock
        create_bd_pin -dir I gt_refclk
        create_bd_pin -dir O hard_err
        create_bd_pin -dir I reset
        create_bd_pin -dir I -type clk s_aclk
        create_bd_pin -dir I -type rst s_aresetn

        # Create instance: aurora, and set properties
        set aurora [ create_bd_cell -type ip -vlnv xilinx.com:ip:aurora_8b10b aurora ]
        set_property -dict [ list \
            CONFIG.CHANNEL_ENABLE {X0Y11} \
            CONFIG.C_DRP_IF {true} \
            CONFIG.C_LANE_WIDTH {4} \
            CONFIG.C_LINE_RATE {6.25} \
            CONFIG.C_REFCLK_FREQUENCY {125} \
            CONFIG.C_REFCLK_SOURCE {MGTREFCLK0 of Quad X0Y2} \
            CONFIG.C_START_LANE {X0Y11} \
            CONFIG.C_START_QUAD {Quad_X0Y2} \
            CONFIG.Interface_Mode {Streaming} \
            ] $aurora

        # Create instance: axi_c2c, and set properties
        set axi_c2c [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_chip2chip axi_c2c ]
        set_property -dict [ list \
            CONFIG.C_AURORA_WIDTH {1} \
            CONFIG.C_ECC_ENABLE {false} \
            CONFIG.C_EN_AXI_LINK_HNDLR {true} \
            CONFIG.C_INTERFACE_MODE {1} \
            CONFIG.C_INTERFACE_TYPE {3} \
            ] $axi_c2c

        # Create instance: buf_gt, and set properties
        set buf_gt [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_ds_buf buf_gt ]
        set_property -dict [ list \
            CONFIG.C_BUF_TYPE {BUFG_GT} \
            ] $buf_gt

        # Create instance: const_0, and set properties
        set const_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_0 ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            ] $const_0

        # Create instance: const_1, and set properties
        set const_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_1 ]

        # Create instance: const_drpaddr, and set properties
        set const_drpaddr [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_drpaddr ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {10} \
            ] $const_drpaddr

        # Create instance: const_drpdi, and set properties
        set const_drpdi [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_drpdi ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {16} \
            ] $const_drpdi

        # Create instance: const_gt_div, and set properties
        set const_gt_div [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_gt_div ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {3} \
            ] $const_gt_div

        # Create interface connections
        connect_bd_intf_net -intf_net GT_RX_1 [get_bd_intf_pins GT_RX] [get_bd_intf_pins aurora/GT_SERIAL_RX]
        connect_bd_intf_net -intf_net aurora_GT_SERIAL_TX [get_bd_intf_pins GT_TX] [get_bd_intf_pins aurora/GT_SERIAL_TX]
        connect_bd_intf_net -intf_net aurora_USER_DATA_M_AXI_RX [get_bd_intf_pins aurora/USER_DATA_M_AXI_RX] [get_bd_intf_pins axi_c2c/AXIS_RX]
        connect_bd_intf_net -intf_net axi_c2c_AXIS_TX [get_bd_intf_pins aurora/USER_DATA_S_AXI_TX] [get_bd_intf_pins axi_c2c/AXIS_TX]
        connect_bd_intf_net -intf_net axi_c2c_xbar_0_M00_AXI [get_bd_intf_pins s_axi] [get_bd_intf_pins axi_c2c/s_axi]

        # Create port connections
        connect_bd_net -net aclk_0_1 [get_bd_pins s_aclk] [get_bd_pins axi_c2c/s_aclk]
        connect_bd_net -net aresetn_0_1 [get_bd_pins s_aresetn] [get_bd_pins axi_c2c/s_aresetn]
        connect_bd_net -net aurora_64b66b_channel_up [get_bd_pins channel_up] [get_bd_pins aurora/channel_up] [get_bd_pins axi_c2c/axi_c2c_aurora_channel_up]
        connect_bd_net -net aurora_bufg_gt_clr_out [get_bd_pins aurora/bufg_gt_clr_out] [get_bd_pins axi_c2c/aurora_mmcm_not_locked] [get_bd_pins buf_gt/BUFG_GT_CLR]
        connect_bd_net -net aurora_hard_err [get_bd_pins hard_err] [get_bd_pins aurora/hard_err]
        connect_bd_net -net aurora_init_clk_0_1 [get_bd_pins aurora_init_clk] [get_bd_pins aurora/init_clk_in] [get_bd_pins axi_c2c/aurora_init_clk]
        connect_bd_net -net aurora_tx_lock [get_bd_pins gt_pll_lock] [get_bd_pins aurora/tx_lock]
        connect_bd_net -net aurora_tx_out_clk [get_bd_pins aurora/tx_out_clk] [get_bd_pins buf_gt/BUFG_GT_I]
        connect_bd_net -net axi_c2c_aurora_pma_init_out [get_bd_pins aurora/gt_reset] [get_bd_pins axi_c2c/aurora_pma_init_out]
        connect_bd_net -net axi_c2c_aurora_reset_pb [get_bd_pins aurora/reset] [get_bd_pins axi_c2c/aurora_reset_pb]
        connect_bd_net -net axi_c2c_axi_c2c_config_error_out [get_bd_pins axi_c2c_config_error] [get_bd_pins axi_c2c/axi_c2c_config_error_out]
        connect_bd_net -net axi_c2c_axi_c2c_link_error_out [get_bd_pins axi_c2c_link_error] [get_bd_pins axi_c2c/axi_c2c_link_error_out]
        connect_bd_net -net axi_c2c_axi_c2c_link_status_out [get_bd_pins axi_c2c_link_status] [get_bd_pins axi_c2c/axi_c2c_link_status_out]
        connect_bd_net -net axi_c2c_axi_c2c_multi_bit_error_out [get_bd_pins axi_c2c_multi_bit_error] [get_bd_pins axi_c2c/axi_c2c_multi_bit_error_out]
        connect_bd_net -net buf_gt_BUFG_GT_O [get_bd_pins aurora/sync_clk] [get_bd_pins aurora/user_clk] [get_bd_pins axi_c2c/axi_c2c_phy_clk] [get_bd_pins buf_gt/BUFG_GT_O]
        connect_bd_net -net const_0_dout [get_bd_pins buf_gt/BUFG_GT_DIV] [get_bd_pins const_gt_div/dout]
        connect_bd_net -net const_0_dout1 [get_bd_pins aurora/gt0_drpen] [get_bd_pins aurora/gt0_drpwe] [get_bd_pins buf_gt/BUFG_GT_CEMASK] [get_bd_pins buf_gt/BUFG_GT_CLRMASK] [get_bd_pins const_0/dout]
        connect_bd_net -net const_1_dout [get_bd_pins buf_gt/BUFG_GT_CE] [get_bd_pins const_1/dout]
        connect_bd_net -net const_drpaddr_dout [get_bd_pins aurora/gt0_drpaddr] [get_bd_pins const_drpaddr/dout]
        connect_bd_net -net const_drpdi_dout [get_bd_pins aurora/gt0_drpdi] [get_bd_pins const_drpdi/dout]
        connect_bd_net -net gt_refclk_1 [get_bd_pins gt_refclk] [get_bd_pins aurora/gt_refclk1]
        connect_bd_net -net reset_1 [get_bd_pins reset] [get_bd_pins axi_c2c/aurora_pma_init_in]

        # Restore current instance
        current_bd_instance $oldCurInst
    }

    # Hierarchical cell: link_3
    proc create_hier_cell_link_3 { parentCell nameHier } {

        variable script_folder

        if { $parentCell eq "" || $nameHier eq "" } {
            catch {common::send_msg_id "BD_TCL-102" "ERROR" "create_hier_cell_link_3() - Empty argument(s)!"}
            return
        }

        # Get object for parentCell
        set parentObj [get_bd_cells $parentCell]
        if { $parentObj == "" } {
            catch {common::send_msg_id "BD_TCL-100" "ERROR" "Unable to find parent cell <$parentCell>!"}
            return
        }

        # Make sure parentObj is hier blk
        set parentType [get_property TYPE $parentObj]
        if { $parentType ne "hier" } {
            catch {common::send_msg_id "BD_TCL-101" "ERROR" "Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."}
            return
        }

        # Save current instance; Restore later
        set oldCurInst [current_bd_instance .]

        # Set parent object as current
        current_bd_instance $parentObj

        # Create cell and set as current instance
        set hier_obj [create_bd_cell -type hier $nameHier]
        current_bd_instance $hier_obj

        # Create interface pins
        create_bd_intf_pin -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 GT_RX

        create_bd_intf_pin -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 GT_TX

        create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 s_axi


        # Create pins
        create_bd_pin -dir I -type clk aurora_init_clk
        create_bd_pin -dir O axi_c2c_config_error
        create_bd_pin -dir O axi_c2c_link_error
        create_bd_pin -dir O axi_c2c_link_status
        create_bd_pin -dir O axi_c2c_multi_bit_error
        create_bd_pin -dir O channel_up
        create_bd_pin -dir O gt_pll_lock
        create_bd_pin -dir I gt_refclk
        create_bd_pin -dir O hard_err
        create_bd_pin -dir I reset
        create_bd_pin -dir I -type clk s_aclk
        create_bd_pin -dir I -type rst s_aresetn

        # Create instance: aurora, and set properties
        set aurora [ create_bd_cell -type ip -vlnv xilinx.com:ip:aurora_8b10b aurora ]
        set_property -dict [ list \
            CONFIG.CHANNEL_ENABLE {X0Y16} \
            CONFIG.C_DRP_IF {true} \
            CONFIG.C_LANE_WIDTH {4} \
            CONFIG.C_LINE_RATE {6.25} \
            CONFIG.C_REFCLK_FREQUENCY {125} \
            CONFIG.C_REFCLK_SOURCE {MGTREFCLK0 of Quad X0Y4} \
            CONFIG.C_START_LANE {X0Y16} \
            CONFIG.C_START_QUAD {Quad_X0Y4} \
            CONFIG.Interface_Mode {Streaming} \
            ] $aurora

        # Create instance: axi_c2c, and set properties
        set axi_c2c [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_chip2chip axi_c2c ]
        set_property -dict [ list \
            CONFIG.C_AURORA_WIDTH {1} \
            CONFIG.C_ECC_ENABLE {false} \
            CONFIG.C_EN_AXI_LINK_HNDLR {true} \
            CONFIG.C_INTERFACE_MODE {1} \
            CONFIG.C_INTERFACE_TYPE {3} \
            ] $axi_c2c

        # Create instance: buf_gt, and set properties
        set buf_gt [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_ds_buf buf_gt ]
        set_property -dict [ list \
            CONFIG.C_BUF_TYPE {BUFG_GT} \
            ] $buf_gt

        # Create instance: const_0, and set properties
        set const_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_0 ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            ] $const_0

        # Create instance: const_1, and set properties
        set const_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_1 ]

        # Create instance: const_drpaddr, and set properties
        set const_drpaddr [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_drpaddr ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {10} \
            ] $const_drpaddr

        # Create instance: const_drpdi, and set properties
        set const_drpdi [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_drpdi ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {16} \
            ] $const_drpdi

        # Create instance: const_gt_div, and set properties
        set const_gt_div [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_gt_div ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {3} \
            ] $const_gt_div

        # Create interface connections
        connect_bd_intf_net -intf_net GT_RX_1 [get_bd_intf_pins GT_RX] [get_bd_intf_pins aurora/GT_SERIAL_RX]
        connect_bd_intf_net -intf_net aurora_GT_SERIAL_TX [get_bd_intf_pins GT_TX] [get_bd_intf_pins aurora/GT_SERIAL_TX]
        connect_bd_intf_net -intf_net aurora_USER_DATA_M_AXI_RX [get_bd_intf_pins aurora/USER_DATA_M_AXI_RX] [get_bd_intf_pins axi_c2c/AXIS_RX]
        connect_bd_intf_net -intf_net axi_c2c_AXIS_TX [get_bd_intf_pins aurora/USER_DATA_S_AXI_TX] [get_bd_intf_pins axi_c2c/AXIS_TX]
        connect_bd_intf_net -intf_net axi_c2c_xbar_0_M00_AXI [get_bd_intf_pins s_axi] [get_bd_intf_pins axi_c2c/s_axi]

        # Create port connections
        connect_bd_net -net aclk_0_1 [get_bd_pins s_aclk] [get_bd_pins axi_c2c/s_aclk]
        connect_bd_net -net aresetn_0_1 [get_bd_pins s_aresetn] [get_bd_pins axi_c2c/s_aresetn]
        connect_bd_net -net aurora_64b66b_channel_up [get_bd_pins channel_up] [get_bd_pins aurora/channel_up] [get_bd_pins axi_c2c/axi_c2c_aurora_channel_up]
        connect_bd_net -net aurora_bufg_gt_clr_out [get_bd_pins aurora/bufg_gt_clr_out] [get_bd_pins axi_c2c/aurora_mmcm_not_locked] [get_bd_pins buf_gt/BUFG_GT_CLR]
        connect_bd_net -net aurora_hard_err [get_bd_pins hard_err] [get_bd_pins aurora/hard_err]
        connect_bd_net -net aurora_init_clk_0_1 [get_bd_pins aurora_init_clk] [get_bd_pins aurora/init_clk_in] [get_bd_pins axi_c2c/aurora_init_clk]
        connect_bd_net -net aurora_tx_lock [get_bd_pins gt_pll_lock] [get_bd_pins aurora/tx_lock]
        connect_bd_net -net aurora_tx_out_clk [get_bd_pins aurora/tx_out_clk] [get_bd_pins buf_gt/BUFG_GT_I]
        connect_bd_net -net axi_c2c_aurora_pma_init_out [get_bd_pins aurora/gt_reset] [get_bd_pins axi_c2c/aurora_pma_init_out]
        connect_bd_net -net axi_c2c_aurora_reset_pb [get_bd_pins aurora/reset] [get_bd_pins axi_c2c/aurora_reset_pb]
        connect_bd_net -net axi_c2c_axi_c2c_config_error_out [get_bd_pins axi_c2c_config_error] [get_bd_pins axi_c2c/axi_c2c_config_error_out]
        connect_bd_net -net axi_c2c_axi_c2c_link_error_out [get_bd_pins axi_c2c_link_error] [get_bd_pins axi_c2c/axi_c2c_link_error_out]
        connect_bd_net -net axi_c2c_axi_c2c_link_status_out [get_bd_pins axi_c2c_link_status] [get_bd_pins axi_c2c/axi_c2c_link_status_out]
        connect_bd_net -net axi_c2c_axi_c2c_multi_bit_error_out [get_bd_pins axi_c2c_multi_bit_error] [get_bd_pins axi_c2c/axi_c2c_multi_bit_error_out]
        connect_bd_net -net buf_gt_BUFG_GT_O [get_bd_pins aurora/sync_clk] [get_bd_pins aurora/user_clk] [get_bd_pins axi_c2c/axi_c2c_phy_clk] [get_bd_pins buf_gt/BUFG_GT_O]
        connect_bd_net -net const_0_dout [get_bd_pins buf_gt/BUFG_GT_DIV] [get_bd_pins const_gt_div/dout]
        connect_bd_net -net const_0_dout1 [get_bd_pins aurora/gt0_drpen] [get_bd_pins aurora/gt0_drpwe] [get_bd_pins buf_gt/BUFG_GT_CEMASK] [get_bd_pins buf_gt/BUFG_GT_CLRMASK] [get_bd_pins const_0/dout]
        connect_bd_net -net const_1_dout [get_bd_pins buf_gt/BUFG_GT_CE] [get_bd_pins const_1/dout]
        connect_bd_net -net const_drpaddr_dout [get_bd_pins aurora/gt0_drpaddr] [get_bd_pins const_drpaddr/dout]
        connect_bd_net -net const_drpdi_dout [get_bd_pins aurora/gt0_drpdi] [get_bd_pins const_drpdi/dout]
        connect_bd_net -net gt_refclk_1 [get_bd_pins gt_refclk] [get_bd_pins aurora/gt_refclk1]
        connect_bd_net -net reset_1 [get_bd_pins reset] [get_bd_pins axi_c2c/aurora_pma_init_in]

        # Restore current instance
        current_bd_instance $oldCurInst
    }

    # Hierarchical cell: link_2
    proc create_hier_cell_link_2 { parentCell nameHier } {

        variable script_folder

        if { $parentCell eq "" || $nameHier eq "" } {
            catch {common::send_msg_id "BD_TCL-102" "ERROR" "create_hier_cell_link_2() - Empty argument(s)!"}
            return
        }

        # Get object for parentCell
        set parentObj [get_bd_cells $parentCell]
        if { $parentObj == "" } {
            catch {common::send_msg_id "BD_TCL-100" "ERROR" "Unable to find parent cell <$parentCell>!"}
            return
        }

        # Make sure parentObj is hier blk
        set parentType [get_property TYPE $parentObj]
        if { $parentType ne "hier" } {
            catch {common::send_msg_id "BD_TCL-101" "ERROR" "Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."}
            return
        }

        # Save current instance; Restore later
        set oldCurInst [current_bd_instance .]

        # Set parent object as current
        current_bd_instance $parentObj

        # Create cell and set as current instance
        set hier_obj [create_bd_cell -type hier $nameHier]
        current_bd_instance $hier_obj

        # Create interface pins
        create_bd_intf_pin -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 GT_RX

        create_bd_intf_pin -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 GT_TX

        create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 s_axi


        # Create pins
        create_bd_pin -dir I -type clk aurora_init_clk
        create_bd_pin -dir O axi_c2c_config_error
        create_bd_pin -dir O axi_c2c_link_error
        create_bd_pin -dir O axi_c2c_link_status
        create_bd_pin -dir O axi_c2c_multi_bit_error
        create_bd_pin -dir O channel_up
        create_bd_pin -dir O gt_pll_lock
        create_bd_pin -dir I gt_refclk
        create_bd_pin -dir O hard_err
        create_bd_pin -dir I reset
        create_bd_pin -dir I -type clk s_aclk
        create_bd_pin -dir I -type rst s_aresetn

        # Create instance: aurora, and set properties
        set aurora [ create_bd_cell -type ip -vlnv xilinx.com:ip:aurora_8b10b aurora ]
        set_property -dict [ list \
            CONFIG.CHANNEL_ENABLE {X0Y17} \
            CONFIG.C_DRP_IF {true} \
            CONFIG.C_LANE_WIDTH {4} \
            CONFIG.C_LINE_RATE {6.25} \
            CONFIG.C_REFCLK_FREQUENCY {125} \
            CONFIG.C_REFCLK_SOURCE {MGTREFCLK0 of Quad X0Y4} \
            CONFIG.C_START_LANE {X0Y17} \
            CONFIG.C_START_QUAD {Quad_X0Y4} \
            CONFIG.Interface_Mode {Streaming} \
            ] $aurora

        # Create instance: axi_c2c, and set properties
        set axi_c2c [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_chip2chip axi_c2c ]
        set_property -dict [ list \
            CONFIG.C_AURORA_WIDTH {1} \
            CONFIG.C_ECC_ENABLE {false} \
            CONFIG.C_EN_AXI_LINK_HNDLR {true} \
            CONFIG.C_INTERFACE_MODE {1} \
            CONFIG.C_INTERFACE_TYPE {3} \
            ] $axi_c2c

        # Create instance: buf_gt, and set properties
        set buf_gt [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_ds_buf buf_gt ]
        set_property -dict [ list \
            CONFIG.C_BUF_TYPE {BUFG_GT} \
            ] $buf_gt

        # Create instance: const_0, and set properties
        set const_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_0 ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            ] $const_0

        # Create instance: const_1, and set properties
        set const_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_1 ]

        # Create instance: const_drpaddr, and set properties
        set const_drpaddr [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_drpaddr ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {10} \
            ] $const_drpaddr

        # Create instance: const_drpdi, and set properties
        set const_drpdi [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_drpdi ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {16} \
            ] $const_drpdi

        # Create instance: const_gt_div, and set properties
        set const_gt_div [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_gt_div ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {3} \
            ] $const_gt_div

        # Create interface connections
        connect_bd_intf_net -intf_net GT_RX_1 [get_bd_intf_pins GT_RX] [get_bd_intf_pins aurora/GT_SERIAL_RX]
        connect_bd_intf_net -intf_net aurora_GT_SERIAL_TX [get_bd_intf_pins GT_TX] [get_bd_intf_pins aurora/GT_SERIAL_TX]
        connect_bd_intf_net -intf_net aurora_USER_DATA_M_AXI_RX [get_bd_intf_pins aurora/USER_DATA_M_AXI_RX] [get_bd_intf_pins axi_c2c/AXIS_RX]
        connect_bd_intf_net -intf_net axi_c2c_AXIS_TX [get_bd_intf_pins aurora/USER_DATA_S_AXI_TX] [get_bd_intf_pins axi_c2c/AXIS_TX]
        connect_bd_intf_net -intf_net axi_c2c_xbar_0_M00_AXI [get_bd_intf_pins s_axi] [get_bd_intf_pins axi_c2c/s_axi]

        # Create port connections
        connect_bd_net -net aclk_0_1 [get_bd_pins s_aclk] [get_bd_pins axi_c2c/s_aclk]
        connect_bd_net -net aresetn_0_1 [get_bd_pins s_aresetn] [get_bd_pins axi_c2c/s_aresetn]
        connect_bd_net -net aurora_64b66b_channel_up [get_bd_pins channel_up] [get_bd_pins aurora/channel_up] [get_bd_pins axi_c2c/axi_c2c_aurora_channel_up]
        connect_bd_net -net aurora_bufg_gt_clr_out [get_bd_pins aurora/bufg_gt_clr_out] [get_bd_pins axi_c2c/aurora_mmcm_not_locked] [get_bd_pins buf_gt/BUFG_GT_CLR]
        connect_bd_net -net aurora_hard_err [get_bd_pins hard_err] [get_bd_pins aurora/hard_err]
        connect_bd_net -net aurora_init_clk_0_1 [get_bd_pins aurora_init_clk] [get_bd_pins aurora/init_clk_in] [get_bd_pins axi_c2c/aurora_init_clk]
        connect_bd_net -net aurora_tx_lock [get_bd_pins gt_pll_lock] [get_bd_pins aurora/tx_lock]
        connect_bd_net -net aurora_tx_out_clk [get_bd_pins aurora/tx_out_clk] [get_bd_pins buf_gt/BUFG_GT_I]
        connect_bd_net -net axi_c2c_aurora_pma_init_out [get_bd_pins aurora/gt_reset] [get_bd_pins axi_c2c/aurora_pma_init_out]
        connect_bd_net -net axi_c2c_aurora_reset_pb [get_bd_pins aurora/reset] [get_bd_pins axi_c2c/aurora_reset_pb]
        connect_bd_net -net axi_c2c_axi_c2c_config_error_out [get_bd_pins axi_c2c_config_error] [get_bd_pins axi_c2c/axi_c2c_config_error_out]
        connect_bd_net -net axi_c2c_axi_c2c_link_error_out [get_bd_pins axi_c2c_link_error] [get_bd_pins axi_c2c/axi_c2c_link_error_out]
        connect_bd_net -net axi_c2c_axi_c2c_link_status_out [get_bd_pins axi_c2c_link_status] [get_bd_pins axi_c2c/axi_c2c_link_status_out]
        connect_bd_net -net axi_c2c_axi_c2c_multi_bit_error_out [get_bd_pins axi_c2c_multi_bit_error] [get_bd_pins axi_c2c/axi_c2c_multi_bit_error_out]
        connect_bd_net -net buf_gt_BUFG_GT_O [get_bd_pins aurora/sync_clk] [get_bd_pins aurora/user_clk] [get_bd_pins axi_c2c/axi_c2c_phy_clk] [get_bd_pins buf_gt/BUFG_GT_O]
        connect_bd_net -net const_0_dout [get_bd_pins buf_gt/BUFG_GT_DIV] [get_bd_pins const_gt_div/dout]
        connect_bd_net -net const_0_dout1 [get_bd_pins aurora/gt0_drpen] [get_bd_pins aurora/gt0_drpwe] [get_bd_pins buf_gt/BUFG_GT_CEMASK] [get_bd_pins buf_gt/BUFG_GT_CLRMASK] [get_bd_pins const_0/dout]
        connect_bd_net -net const_1_dout [get_bd_pins buf_gt/BUFG_GT_CE] [get_bd_pins const_1/dout]
        connect_bd_net -net const_drpaddr_dout [get_bd_pins aurora/gt0_drpaddr] [get_bd_pins const_drpaddr/dout]
        connect_bd_net -net const_drpdi_dout [get_bd_pins aurora/gt0_drpdi] [get_bd_pins const_drpdi/dout]
        connect_bd_net -net gt_refclk_1 [get_bd_pins gt_refclk] [get_bd_pins aurora/gt_refclk1]
        connect_bd_net -net reset_1 [get_bd_pins reset] [get_bd_pins axi_c2c/aurora_pma_init_in]

        # Restore current instance
        current_bd_instance $oldCurInst
    }

    # Hierarchical cell: link_1
    proc create_hier_cell_link_1 { parentCell nameHier } {

        variable script_folder

        if { $parentCell eq "" || $nameHier eq "" } {
            catch {common::send_msg_id "BD_TCL-102" "ERROR" "create_hier_cell_link_1() - Empty argument(s)!"}
            return
        }

        # Get object for parentCell
        set parentObj [get_bd_cells $parentCell]
        if { $parentObj == "" } {
            catch {common::send_msg_id "BD_TCL-100" "ERROR" "Unable to find parent cell <$parentCell>!"}
            return
        }

        # Make sure parentObj is hier blk
        set parentType [get_property TYPE $parentObj]
        if { $parentType ne "hier" } {
            catch {common::send_msg_id "BD_TCL-101" "ERROR" "Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."}
            return
        }

        # Save current instance; Restore later
        set oldCurInst [current_bd_instance .]

        # Set parent object as current
        current_bd_instance $parentObj

        # Create cell and set as current instance
        set hier_obj [create_bd_cell -type hier $nameHier]
        current_bd_instance $hier_obj

        # Create interface pins
        create_bd_intf_pin -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 GT_RX

        create_bd_intf_pin -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 GT_TX

        create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 s_axi


        # Create pins
        create_bd_pin -dir I -type clk aurora_init_clk
        create_bd_pin -dir O axi_c2c_config_error
        create_bd_pin -dir O axi_c2c_link_error
        create_bd_pin -dir O axi_c2c_link_status
        create_bd_pin -dir O axi_c2c_multi_bit_error
        create_bd_pin -dir O channel_up
        create_bd_pin -dir O gt_pll_lock
        create_bd_pin -dir I gt_refclk
        create_bd_pin -dir O hard_err
        create_bd_pin -dir I reset
        create_bd_pin -dir I -type clk s_aclk
        create_bd_pin -dir I -type rst s_aresetn

        # Create instance: aurora, and set properties
        set aurora [ create_bd_cell -type ip -vlnv xilinx.com:ip:aurora_8b10b aurora ]
        set_property -dict [ list \
            CONFIG.CHANNEL_ENABLE {X0Y18} \
            CONFIG.C_DRP_IF {true} \
            CONFIG.C_LANE_WIDTH {4} \
            CONFIG.C_LINE_RATE {6.25} \
            CONFIG.C_REFCLK_FREQUENCY {125} \
            CONFIG.C_REFCLK_SOURCE {MGTREFCLK0 of Quad X0Y4} \
            CONFIG.C_START_LANE {X0Y18} \
            CONFIG.C_START_QUAD {Quad_X0Y4} \
            CONFIG.Interface_Mode {Streaming} \
            ] $aurora

        # Create instance: axi_c2c, and set properties
        set axi_c2c [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_chip2chip axi_c2c ]
        set_property -dict [ list \
            CONFIG.C_AURORA_WIDTH {1} \
            CONFIG.C_ECC_ENABLE {false} \
            CONFIG.C_EN_AXI_LINK_HNDLR {true} \
            CONFIG.C_INTERFACE_MODE {1} \
            CONFIG.C_INTERFACE_TYPE {3} \
            ] $axi_c2c

        # Create instance: buf_gt, and set properties
        set buf_gt [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_ds_buf buf_gt ]
        set_property -dict [ list \
            CONFIG.C_BUF_TYPE {BUFG_GT} \
            ] $buf_gt

        # Create instance: const_0, and set properties
        set const_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_0 ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            ] $const_0

        # Create instance: const_1, and set properties
        set const_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_1 ]

        # Create instance: const_drpaddr, and set properties
        set const_drpaddr [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_drpaddr ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {10} \
            ] $const_drpaddr

        # Create instance: const_drpdi, and set properties
        set const_drpdi [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_drpdi ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {16} \
            ] $const_drpdi

        # Create instance: const_gt_div, and set properties
        set const_gt_div [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_gt_div ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {3} \
            ] $const_gt_div

        # Create interface connections
        connect_bd_intf_net -intf_net GT_RX_1 [get_bd_intf_pins GT_RX] [get_bd_intf_pins aurora/GT_SERIAL_RX]
        connect_bd_intf_net -intf_net aurora_GT_SERIAL_TX [get_bd_intf_pins GT_TX] [get_bd_intf_pins aurora/GT_SERIAL_TX]
        connect_bd_intf_net -intf_net aurora_USER_DATA_M_AXI_RX [get_bd_intf_pins aurora/USER_DATA_M_AXI_RX] [get_bd_intf_pins axi_c2c/AXIS_RX]
        connect_bd_intf_net -intf_net axi_c2c_AXIS_TX [get_bd_intf_pins aurora/USER_DATA_S_AXI_TX] [get_bd_intf_pins axi_c2c/AXIS_TX]
        connect_bd_intf_net -intf_net axi_c2c_xbar_0_M00_AXI [get_bd_intf_pins s_axi] [get_bd_intf_pins axi_c2c/s_axi]

        # Create port connections
        connect_bd_net -net aclk_0_1 [get_bd_pins s_aclk] [get_bd_pins axi_c2c/s_aclk]
        connect_bd_net -net aresetn_0_1 [get_bd_pins s_aresetn] [get_bd_pins axi_c2c/s_aresetn]
        connect_bd_net -net aurora_64b66b_channel_up [get_bd_pins channel_up] [get_bd_pins aurora/channel_up] [get_bd_pins axi_c2c/axi_c2c_aurora_channel_up]
        connect_bd_net -net aurora_bufg_gt_clr_out [get_bd_pins aurora/bufg_gt_clr_out] [get_bd_pins axi_c2c/aurora_mmcm_not_locked] [get_bd_pins buf_gt/BUFG_GT_CLR]
        connect_bd_net -net aurora_hard_err [get_bd_pins hard_err] [get_bd_pins aurora/hard_err]
        connect_bd_net -net aurora_init_clk_0_1 [get_bd_pins aurora_init_clk] [get_bd_pins aurora/init_clk_in] [get_bd_pins axi_c2c/aurora_init_clk]
        connect_bd_net -net aurora_tx_lock [get_bd_pins gt_pll_lock] [get_bd_pins aurora/tx_lock]
        connect_bd_net -net aurora_tx_out_clk [get_bd_pins aurora/tx_out_clk] [get_bd_pins buf_gt/BUFG_GT_I]
        connect_bd_net -net axi_c2c_aurora_pma_init_out [get_bd_pins aurora/gt_reset] [get_bd_pins axi_c2c/aurora_pma_init_out]
        connect_bd_net -net axi_c2c_aurora_reset_pb [get_bd_pins aurora/reset] [get_bd_pins axi_c2c/aurora_reset_pb]
        connect_bd_net -net axi_c2c_axi_c2c_config_error_out [get_bd_pins axi_c2c_config_error] [get_bd_pins axi_c2c/axi_c2c_config_error_out]
        connect_bd_net -net axi_c2c_axi_c2c_link_error_out [get_bd_pins axi_c2c_link_error] [get_bd_pins axi_c2c/axi_c2c_link_error_out]
        connect_bd_net -net axi_c2c_axi_c2c_link_status_out [get_bd_pins axi_c2c_link_status] [get_bd_pins axi_c2c/axi_c2c_link_status_out]
        connect_bd_net -net axi_c2c_axi_c2c_multi_bit_error_out [get_bd_pins axi_c2c_multi_bit_error] [get_bd_pins axi_c2c/axi_c2c_multi_bit_error_out]
        connect_bd_net -net buf_gt_BUFG_GT_O [get_bd_pins aurora/sync_clk] [get_bd_pins aurora/user_clk] [get_bd_pins axi_c2c/axi_c2c_phy_clk] [get_bd_pins buf_gt/BUFG_GT_O]
        connect_bd_net -net const_0_dout [get_bd_pins buf_gt/BUFG_GT_DIV] [get_bd_pins const_gt_div/dout]
        connect_bd_net -net const_0_dout1 [get_bd_pins aurora/gt0_drpen] [get_bd_pins aurora/gt0_drpwe] [get_bd_pins buf_gt/BUFG_GT_CEMASK] [get_bd_pins buf_gt/BUFG_GT_CLRMASK] [get_bd_pins const_0/dout]
        connect_bd_net -net const_1_dout [get_bd_pins buf_gt/BUFG_GT_CE] [get_bd_pins const_1/dout]
        connect_bd_net -net const_drpaddr_dout [get_bd_pins aurora/gt0_drpaddr] [get_bd_pins const_drpaddr/dout]
        connect_bd_net -net const_drpdi_dout [get_bd_pins aurora/gt0_drpdi] [get_bd_pins const_drpdi/dout]
        connect_bd_net -net gt_refclk_1 [get_bd_pins gt_refclk] [get_bd_pins aurora/gt_refclk1]
        connect_bd_net -net reset_1 [get_bd_pins reset] [get_bd_pins axi_c2c/aurora_pma_init_in]

        # Restore current instance
        current_bd_instance $oldCurInst
    }

    # Hierarchical cell: link_0
    proc create_hier_cell_link_0 { parentCell nameHier } {

        variable script_folder

        if { $parentCell eq "" || $nameHier eq "" } {
            catch {common::send_msg_id "BD_TCL-102" "ERROR" "create_hier_cell_link_0() - Empty argument(s)!"}
            return
        }

        # Get object for parentCell
        set parentObj [get_bd_cells $parentCell]
        if { $parentObj == "" } {
            catch {common::send_msg_id "BD_TCL-100" "ERROR" "Unable to find parent cell <$parentCell>!"}
            return
        }

        # Make sure parentObj is hier blk
        set parentType [get_property TYPE $parentObj]
        if { $parentType ne "hier" } {
            catch {common::send_msg_id "BD_TCL-101" "ERROR" "Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."}
            return
        }

        # Save current instance; Restore later
        set oldCurInst [current_bd_instance .]

        # Set parent object as current
        current_bd_instance $parentObj

        # Create cell and set as current instance
        set hier_obj [create_bd_cell -type hier $nameHier]
        current_bd_instance $hier_obj

        # Create interface pins
        create_bd_intf_pin -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 GT_RX

        create_bd_intf_pin -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 GT_TX

        create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 s_axi


        # Create pins
        create_bd_pin -dir I -type clk aurora_init_clk
        create_bd_pin -dir O axi_c2c_config_error
        create_bd_pin -dir O axi_c2c_link_error
        create_bd_pin -dir O axi_c2c_link_status
        create_bd_pin -dir O axi_c2c_multi_bit_error
        create_bd_pin -dir O channel_up
        create_bd_pin -dir O gt_pll_lock
        create_bd_pin -dir I gt_refclk
        create_bd_pin -dir O hard_err
        create_bd_pin -dir I reset
        create_bd_pin -dir I -type clk s_aclk
        create_bd_pin -dir I -type rst s_aresetn

        # Create instance: aurora, and set properties
        set aurora [ create_bd_cell -type ip -vlnv xilinx.com:ip:aurora_8b10b aurora ]
        set_property -dict [ list \
            CONFIG.CHANNEL_ENABLE {X0Y19} \
            CONFIG.C_DRP_IF {true} \
            CONFIG.C_LANE_WIDTH {4} \
            CONFIG.C_LINE_RATE {6.25} \
            CONFIG.C_REFCLK_FREQUENCY {125} \
            CONFIG.C_REFCLK_SOURCE {MGTREFCLK0 of Quad X0Y4} \
            CONFIG.C_START_LANE {X0Y19} \
            CONFIG.C_START_QUAD {Quad_X0Y4} \
            CONFIG.Interface_Mode {Streaming} \
            CONFIG.TransceiverControl {false} \
            ] $aurora

        # Create instance: axi_c2c, and set properties
        set axi_c2c [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_chip2chip axi_c2c ]
        set_property -dict [ list \
            CONFIG.C_AURORA_WIDTH {1} \
            CONFIG.C_ECC_ENABLE {false} \
            CONFIG.C_EN_AXI_LINK_HNDLR {true} \
            CONFIG.C_INTERFACE_MODE {1} \
            CONFIG.C_INTERFACE_TYPE {3} \
            ] $axi_c2c

        # Create instance: buf_gt, and set properties
        set buf_gt [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_ds_buf buf_gt ]
        set_property -dict [ list \
            CONFIG.C_BUF_TYPE {BUFG_GT} \
            ] $buf_gt

        # Create instance: const_0, and set properties
        set const_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_0 ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            ] $const_0

        # Create instance: const_1, and set properties
        set const_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_1 ]

        # Create instance: const_drpaddr, and set properties
        set const_drpaddr [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_drpaddr ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {10} \
            ] $const_drpaddr

        # Create instance: const_drpdi, and set properties
        set const_drpdi [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_drpdi ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {16} \
            ] $const_drpdi

        # Create instance: const_gt_div, and set properties
        set const_gt_div [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant const_gt_div ]
        set_property -dict [ list \
            CONFIG.CONST_VAL {0} \
            CONFIG.CONST_WIDTH {3} \
            ] $const_gt_div

        # Create interface connections
        connect_bd_intf_net -intf_net GT_RX_1 [get_bd_intf_pins GT_RX] [get_bd_intf_pins aurora/GT_SERIAL_RX]
        connect_bd_intf_net -intf_net aurora_GT_SERIAL_TX [get_bd_intf_pins GT_TX] [get_bd_intf_pins aurora/GT_SERIAL_TX]
        connect_bd_intf_net -intf_net aurora_USER_DATA_M_AXI_RX [get_bd_intf_pins aurora/USER_DATA_M_AXI_RX] [get_bd_intf_pins axi_c2c/AXIS_RX]
        connect_bd_intf_net -intf_net axi_c2c_AXIS_TX [get_bd_intf_pins aurora/USER_DATA_S_AXI_TX] [get_bd_intf_pins axi_c2c/AXIS_TX]
        connect_bd_intf_net -intf_net axi_c2c_xbar_0_M00_AXI [get_bd_intf_pins s_axi] [get_bd_intf_pins axi_c2c/s_axi]

        # Create port connections
        connect_bd_net -net aclk_0_1 [get_bd_pins s_aclk] [get_bd_pins axi_c2c/s_aclk]
        connect_bd_net -net aresetn_0_1 [get_bd_pins s_aresetn] [get_bd_pins axi_c2c/s_aresetn]
        connect_bd_net -net aurora_64b66b_channel_up [get_bd_pins channel_up] [get_bd_pins aurora/channel_up] [get_bd_pins axi_c2c/axi_c2c_aurora_channel_up]
        connect_bd_net -net aurora_bufg_gt_clr_out [get_bd_pins aurora/bufg_gt_clr_out] [get_bd_pins axi_c2c/aurora_mmcm_not_locked] [get_bd_pins buf_gt/BUFG_GT_CLR]
        connect_bd_net -net aurora_hard_err [get_bd_pins hard_err] [get_bd_pins aurora/hard_err]
        connect_bd_net -net aurora_init_clk_0_1 [get_bd_pins aurora_init_clk] [get_bd_pins aurora/init_clk_in] [get_bd_pins axi_c2c/aurora_init_clk]
        connect_bd_net -net aurora_tx_lock [get_bd_pins gt_pll_lock] [get_bd_pins aurora/tx_lock]
        connect_bd_net -net aurora_tx_out_clk [get_bd_pins aurora/tx_out_clk] [get_bd_pins buf_gt/BUFG_GT_I]
        connect_bd_net -net axi_c2c_aurora_pma_init_out [get_bd_pins aurora/gt_reset] [get_bd_pins axi_c2c/aurora_pma_init_out]
        connect_bd_net -net axi_c2c_aurora_reset_pb [get_bd_pins aurora/reset] [get_bd_pins axi_c2c/aurora_reset_pb]
        connect_bd_net -net axi_c2c_axi_c2c_config_error_out [get_bd_pins axi_c2c_config_error] [get_bd_pins axi_c2c/axi_c2c_config_error_out]
        connect_bd_net -net axi_c2c_axi_c2c_link_error_out [get_bd_pins axi_c2c_link_error] [get_bd_pins axi_c2c/axi_c2c_link_error_out]
        connect_bd_net -net axi_c2c_axi_c2c_link_status_out [get_bd_pins axi_c2c_link_status] [get_bd_pins axi_c2c/axi_c2c_link_status_out]
        connect_bd_net -net axi_c2c_axi_c2c_multi_bit_error_out [get_bd_pins axi_c2c_multi_bit_error] [get_bd_pins axi_c2c/axi_c2c_multi_bit_error_out]
        connect_bd_net -net buf_gt_BUFG_GT_O [get_bd_pins aurora/sync_clk] [get_bd_pins aurora/user_clk] [get_bd_pins axi_c2c/axi_c2c_phy_clk] [get_bd_pins buf_gt/BUFG_GT_O]
        connect_bd_net -net const_0_dout [get_bd_pins buf_gt/BUFG_GT_DIV] [get_bd_pins const_gt_div/dout]
        connect_bd_net -net const_0_dout1 [get_bd_pins aurora/gt0_drpen] [get_bd_pins aurora/gt0_drpwe] [get_bd_pins buf_gt/BUFG_GT_CEMASK] [get_bd_pins buf_gt/BUFG_GT_CLRMASK] [get_bd_pins const_0/dout]
        connect_bd_net -net const_1_dout [get_bd_pins buf_gt/BUFG_GT_CE] [get_bd_pins const_1/dout]
        connect_bd_net -net const_drp_addr_dout [get_bd_pins aurora/gt0_drpaddr] [get_bd_pins const_drpaddr/dout]
        connect_bd_net -net const_drpdi_dout [get_bd_pins aurora/gt0_drpdi] [get_bd_pins const_drpdi/dout]
        connect_bd_net -net gt_refclk_1 [get_bd_pins gt_refclk] [get_bd_pins aurora/gt_refclk1]
        connect_bd_net -net reset_1 [get_bd_pins reset] [get_bd_pins axi_c2c/aurora_pma_init_in]

        # Restore current instance
        current_bd_instance $oldCurInst
    }

    # Hierarchical cell: chip2chip_subsystem
    proc create_hier_cell_chip2chip_subsystem { parentCell nameHier } {

        variable script_folder

        if { $parentCell eq "" || $nameHier eq "" } {
            catch {common::send_msg_id "BD_TCL-102" "ERROR" "create_hier_cell_chip2chip_subsystem() - Empty argument(s)!"}
            return
        }

        # Get object for parentCell
        set parentObj [get_bd_cells $parentCell]
        if { $parentObj == "" } {
            catch {common::send_msg_id "BD_TCL-100" "ERROR" "Unable to find parent cell <$parentCell>!"}
            return
        }

        # Make sure parentObj is hier blk
        set parentType [get_property TYPE $parentObj]
        if { $parentType ne "hier" } {
            catch {common::send_msg_id "BD_TCL-101" "ERROR" "Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."}
            return
        }

        # Save current instance; Restore later
        set oldCurInst [current_bd_instance .]

        # Set parent object as current
        current_bd_instance $parentObj

        # Create cell and set as current instance
        set hier_obj [create_bd_cell -type hier $nameHier]
        current_bd_instance $hier_obj
        set_property USER_COMMENTS.comment_0 "1. It could make more sense to instantiate Chip2Chip/Aurora in RTL,
        because it's more convenient to use when generating multiple repeated structures
        (like 8 identical Chip2Chip/Aurora links.
        We could avoid pulling all these status signals through xlconcat IP.
        BUT the Aurora IP **doesn't support** instantiating within RTL *if* that RTL block
        is later included in the block design.
        Don't ask me why, ask Xilinx.
        Requires AR73018 patch to fix Chip2Chip bug" [get_bd_cells /chip2chip_subsystem]

        # Create interface pins
        create_bd_intf_pin -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 GT_RX_0

        create_bd_intf_pin -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 GT_RX_1

        create_bd_intf_pin -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 GT_RX_2

        create_bd_intf_pin -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 GT_RX_3

        create_bd_intf_pin -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 GT_RX_4

        create_bd_intf_pin -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 GT_RX_5

        create_bd_intf_pin -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 GT_RX_6

        create_bd_intf_pin -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 GT_RX_7

        create_bd_intf_pin -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 GT_TX_0

        create_bd_intf_pin -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 GT_TX_1

        create_bd_intf_pin -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 GT_TX_2

        create_bd_intf_pin -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 GT_TX_3

        create_bd_intf_pin -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 GT_TX_4

        create_bd_intf_pin -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 GT_TX_5

        create_bd_intf_pin -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 GT_TX_6

        create_bd_intf_pin -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 GT_TX_7

        create_bd_intf_pin -mode Master -vlnv xilinx.com:interface:aximm_rtl:1.0 M_AXI

        create_bd_intf_pin -mode Master -vlnv xilinx.com:interface:aximm_rtl:1.0 M_AXI_SG

        create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 S_AXI

        create_bd_intf_pin -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 S_AXI_CTRL


        # Create pins
        create_bd_pin -dir I -type clk aurora_init_clk
        create_bd_pin -dir I gt_refclk
        create_bd_pin -dir O -type intr irq
        create_bd_pin -dir I -type clk s_aclk
        create_bd_pin -dir I -type rst s_aresetn

        # Create instance: axi_cdma, and set properties
        set axi_cdma [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_cdma axi_cdma ]
        set_property -dict [ list \
            CONFIG.C_ADDR_WIDTH {40} \
            ] $axi_cdma

        # Create instance: axi_lite_xbar, and set properties
        set axi_lite_xbar [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_crossbar axi_lite_xbar ]
        set_property -dict [ list \
            CONFIG.CONNECTIVITY_MODE {SASD} \
            CONFIG.NUM_MI {2} \
            CONFIG.PROTOCOL {AXI4LITE} \
            CONFIG.S00_SINGLE_THREAD {1} \
            CONFIG.STRATEGY {1} \
            ] $axi_lite_xbar

        # Create instance: axi_main_interconnect, and set properties
        set axi_main_interconnect [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect axi_main_interconnect ]
        set_property -dict [ list \
            CONFIG.ENABLE_ADVANCED_OPTIONS {0} \
            CONFIG.NUM_MI {9} \
            CONFIG.NUM_SI {2} \
            CONFIG.S00_HAS_DATA_FIFO {2} \
            CONFIG.S01_HAS_DATA_FIFO {2} \
            CONFIG.STRATEGY {2} \
            ] $axi_main_interconnect

        # Create instance: c2c_link_ctrl, and set properties
        set block_name c2c_link
        set block_cell_name c2c_link_ctrl
        if { [catch {set c2c_link_ctrl [create_bd_cell -type module -reference $block_name $block_cell_name] } errmsg] } {
            catch {common::send_msg_id "BD_TCL-105" "ERROR" "Unable to add referenced block <$block_name>. Please add the files for ${block_name}'s definition into the project."}
            return 1
        } elseif { $c2c_link_ctrl eq "" } {
            catch {common::send_msg_id "BD_TCL-106" "ERROR" "Unable to referenced block <$block_name>. Please add the files for ${block_name}'s definition into the project."}
            return 1
        }

        # Create instance: link_0
        create_hier_cell_link_0 $hier_obj link_0

        # Create instance: link_1
        create_hier_cell_link_1 $hier_obj link_1

        # Create instance: link_2
        create_hier_cell_link_2 $hier_obj link_2

        # Create instance: link_3
        create_hier_cell_link_3 $hier_obj link_3

        # Create instance: link_4
        create_hier_cell_link_4 $hier_obj link_4

        # Create instance: link_5
        create_hier_cell_link_5 $hier_obj link_5

        # Create instance: link_6
        create_hier_cell_link_6 $hier_obj link_6

        # Create instance: link_7
        create_hier_cell_link_7 $hier_obj link_7

        # Create instance: xlconcat_channel_up, and set properties
        set xlconcat_channel_up [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat xlconcat_channel_up ]
        set_property -dict [ list \
            CONFIG.NUM_PORTS {8} \
            ] $xlconcat_channel_up

        # Create instance: xlconcat_config_error, and set properties
        set xlconcat_config_error [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat xlconcat_config_error ]
        set_property -dict [ list \
            CONFIG.NUM_PORTS {8} \
            ] $xlconcat_config_error

        # Create instance: xlconcat_gt_lock, and set properties
        set xlconcat_gt_lock [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat xlconcat_gt_lock ]
        set_property -dict [ list \
            CONFIG.NUM_PORTS {8} \
            ] $xlconcat_gt_lock

        # Create instance: xlconcat_hard_err, and set properties
        set xlconcat_hard_err [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat xlconcat_hard_err ]
        set_property -dict [ list \
            CONFIG.NUM_PORTS {8} \
            ] $xlconcat_hard_err

        # Create instance: xlconcat_link_error, and set properties
        set xlconcat_link_error [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat xlconcat_link_error ]
        set_property -dict [ list \
            CONFIG.NUM_PORTS {8} \
            ] $xlconcat_link_error

        # Create instance: xlconcat_link_status, and set properties
        set xlconcat_link_status [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat xlconcat_link_status ]
        set_property -dict [ list \
            CONFIG.NUM_PORTS {8} \
            ] $xlconcat_link_status

        # Create instance: xlconcat_mbit_error, and set properties
        set xlconcat_mbit_error [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat xlconcat_mbit_error ]
        set_property -dict [ list \
            CONFIG.NUM_PORTS {8} \
            ] $xlconcat_mbit_error

        # Create interface connections
        connect_bd_intf_net -intf_net Conn1 [get_bd_intf_pins S_AXI] [get_bd_intf_pins axi_main_interconnect/S00_AXI]
        connect_bd_intf_net -intf_net Conn2 [get_bd_intf_pins S_AXI_CTRL] [get_bd_intf_pins axi_lite_xbar/S00_AXI]
        connect_bd_intf_net -intf_net Conn5 [get_bd_intf_pins GT_TX_0] [get_bd_intf_pins link_0/GT_TX]
        connect_bd_intf_net -intf_net Conn6 [get_bd_intf_pins GT_RX_0] [get_bd_intf_pins link_0/GT_RX]
        connect_bd_intf_net -intf_net Conn7 [get_bd_intf_pins GT_TX_1] [get_bd_intf_pins link_1/GT_TX]
        connect_bd_intf_net -intf_net Conn8 [get_bd_intf_pins GT_RX_1] [get_bd_intf_pins link_1/GT_RX]
        connect_bd_intf_net -intf_net Conn9 [get_bd_intf_pins GT_TX_2] [get_bd_intf_pins link_2/GT_TX]
        connect_bd_intf_net -intf_net Conn10 [get_bd_intf_pins GT_RX_2] [get_bd_intf_pins link_2/GT_RX]
        connect_bd_intf_net -intf_net Conn11 [get_bd_intf_pins GT_TX_3] [get_bd_intf_pins link_3/GT_TX]
        connect_bd_intf_net -intf_net Conn12 [get_bd_intf_pins GT_RX_3] [get_bd_intf_pins link_3/GT_RX]
        connect_bd_intf_net -intf_net Conn13 [get_bd_intf_pins GT_TX_4] [get_bd_intf_pins link_4/GT_TX]
        connect_bd_intf_net -intf_net Conn14 [get_bd_intf_pins GT_RX_4] [get_bd_intf_pins link_4/GT_RX]
        connect_bd_intf_net -intf_net Conn15 [get_bd_intf_pins GT_TX_5] [get_bd_intf_pins link_5/GT_TX]
        connect_bd_intf_net -intf_net Conn16 [get_bd_intf_pins GT_RX_5] [get_bd_intf_pins link_5/GT_RX]
        connect_bd_intf_net -intf_net Conn17 [get_bd_intf_pins GT_TX_6] [get_bd_intf_pins link_6/GT_TX]
        connect_bd_intf_net -intf_net Conn18 [get_bd_intf_pins GT_RX_6] [get_bd_intf_pins link_6/GT_RX]
        connect_bd_intf_net -intf_net Conn19 [get_bd_intf_pins GT_TX_7] [get_bd_intf_pins link_7/GT_TX]
        connect_bd_intf_net -intf_net Conn20 [get_bd_intf_pins GT_RX_7] [get_bd_intf_pins link_7/GT_RX]
        connect_bd_intf_net -intf_net axi_cdma_0_M_AXI [get_bd_intf_pins axi_cdma/M_AXI] [get_bd_intf_pins axi_main_interconnect/S01_AXI]
        connect_bd_intf_net -intf_net axi_cdma_0_M_AXI_SG [get_bd_intf_pins M_AXI_SG] [get_bd_intf_pins axi_cdma/M_AXI_SG]
        connect_bd_intf_net -intf_net axi_crossbar_0_M00_AXI [get_bd_intf_pins axi_cdma/S_AXI_LITE] [get_bd_intf_pins axi_lite_xbar/M00_AXI]
        connect_bd_intf_net -intf_net axi_lite_xbar_M01_AXI [get_bd_intf_pins axi_lite_xbar/M01_AXI] [get_bd_intf_pins c2c_link_ctrl/s_axi]
        connect_bd_intf_net -intf_net axi_main_interconnect_M08_AXI [get_bd_intf_pins M_AXI] [get_bd_intf_pins axi_main_interconnect/M08_AXI]
        connect_bd_intf_net -intf_net s_axi_1 [get_bd_intf_pins axi_main_interconnect/M07_AXI] [get_bd_intf_pins link_7/s_axi]
        connect_bd_intf_net -intf_net s_axi_2 [get_bd_intf_pins axi_main_interconnect/M06_AXI] [get_bd_intf_pins link_6/s_axi]
        connect_bd_intf_net -intf_net s_axi_3 [get_bd_intf_pins axi_main_interconnect/M05_AXI] [get_bd_intf_pins link_5/s_axi]
        connect_bd_intf_net -intf_net s_axi_4 [get_bd_intf_pins axi_main_interconnect/M02_AXI] [get_bd_intf_pins link_2/s_axi]
        connect_bd_intf_net -intf_net s_axi_5 [get_bd_intf_pins axi_main_interconnect/M04_AXI] [get_bd_intf_pins link_4/s_axi]
        connect_bd_intf_net -intf_net s_axi_6 [get_bd_intf_pins axi_main_interconnect/M01_AXI] [get_bd_intf_pins link_1/s_axi]
        connect_bd_intf_net -intf_net s_axi_7 [get_bd_intf_pins axi_main_interconnect/M00_AXI] [get_bd_intf_pins link_0/s_axi]
        connect_bd_intf_net -intf_net s_axi_8 [get_bd_intf_pins axi_main_interconnect/M03_AXI] [get_bd_intf_pins link_3/s_axi]

        # Create port connections
        connect_bd_net -net aclk_0_1 [get_bd_pins s_aclk] [get_bd_pins axi_cdma/m_axi_aclk] [get_bd_pins axi_cdma/s_axi_lite_aclk] [get_bd_pins axi_lite_xbar/aclk] [get_bd_pins axi_main_interconnect/ACLK] [get_bd_pins axi_main_interconnect/M00_ACLK] [get_bd_pins axi_main_interconnect/M01_ACLK] [get_bd_pins axi_main_interconnect/M02_ACLK] [get_bd_pins axi_main_interconnect/M03_ACLK] [get_bd_pins axi_main_interconnect/M04_ACLK] [get_bd_pins axi_main_interconnect/M05_ACLK] [get_bd_pins axi_main_interconnect/M06_ACLK] [get_bd_pins axi_main_interconnect/M07_ACLK] [get_bd_pins axi_main_interconnect/M08_ACLK] [get_bd_pins axi_main_interconnect/S00_ACLK] [get_bd_pins axi_main_interconnect/S01_ACLK] [get_bd_pins c2c_link_ctrl/s_axi_aclk] [get_bd_pins link_0/s_aclk] [get_bd_pins link_1/s_aclk] [get_bd_pins link_2/s_aclk] [get_bd_pins link_3/s_aclk] [get_bd_pins link_4/s_aclk] [get_bd_pins link_5/s_aclk] [get_bd_pins link_6/s_aclk] [get_bd_pins link_7/s_aclk]
        connect_bd_net -net aresetn_0_1 [get_bd_pins s_aresetn] [get_bd_pins axi_cdma/s_axi_lite_aresetn] [get_bd_pins axi_lite_xbar/aresetn] [get_bd_pins axi_main_interconnect/ARESETN] [get_bd_pins axi_main_interconnect/M00_ARESETN] [get_bd_pins axi_main_interconnect/M01_ARESETN] [get_bd_pins axi_main_interconnect/M02_ARESETN] [get_bd_pins axi_main_interconnect/M03_ARESETN] [get_bd_pins axi_main_interconnect/M04_ARESETN] [get_bd_pins axi_main_interconnect/M05_ARESETN] [get_bd_pins axi_main_interconnect/M06_ARESETN] [get_bd_pins axi_main_interconnect/M07_ARESETN] [get_bd_pins axi_main_interconnect/M08_ARESETN] [get_bd_pins axi_main_interconnect/S00_ARESETN] [get_bd_pins axi_main_interconnect/S01_ARESETN] [get_bd_pins c2c_link_ctrl/s_axi_aresetn] [get_bd_pins link_0/s_aresetn] [get_bd_pins link_1/s_aresetn] [get_bd_pins link_2/s_aresetn] [get_bd_pins link_3/s_aresetn] [get_bd_pins link_4/s_aresetn] [get_bd_pins link_5/s_aresetn] [get_bd_pins link_6/s_aresetn] [get_bd_pins link_7/s_aresetn]
        connect_bd_net -net aurora_init_clk_0_1 [get_bd_pins aurora_init_clk] [get_bd_pins link_0/aurora_init_clk] [get_bd_pins link_1/aurora_init_clk] [get_bd_pins link_2/aurora_init_clk] [get_bd_pins link_3/aurora_init_clk] [get_bd_pins link_4/aurora_init_clk] [get_bd_pins link_5/aurora_init_clk] [get_bd_pins link_6/aurora_init_clk] [get_bd_pins link_7/aurora_init_clk]
        connect_bd_net -net axi_cdma_cdma_introut [get_bd_pins irq] [get_bd_pins axi_cdma/cdma_introut]
        connect_bd_net -net c2c_link_ctrl_reset_0 [get_bd_pins c2c_link_ctrl/reset_0] [get_bd_pins link_0/reset]
        connect_bd_net -net c2c_link_ctrl_reset_1 [get_bd_pins c2c_link_ctrl/reset_1] [get_bd_pins link_1/reset]
        connect_bd_net -net c2c_link_ctrl_reset_2 [get_bd_pins c2c_link_ctrl/reset_2] [get_bd_pins link_2/reset]
        connect_bd_net -net c2c_link_ctrl_reset_3 [get_bd_pins c2c_link_ctrl/reset_3] [get_bd_pins link_3/reset]
        connect_bd_net -net c2c_link_ctrl_reset_4 [get_bd_pins c2c_link_ctrl/reset_4] [get_bd_pins link_4/reset]
        connect_bd_net -net c2c_link_ctrl_reset_5 [get_bd_pins c2c_link_ctrl/reset_5] [get_bd_pins link_5/reset]
        connect_bd_net -net c2c_link_ctrl_reset_6 [get_bd_pins c2c_link_ctrl/reset_6] [get_bd_pins link_6/reset]
        connect_bd_net -net c2c_link_ctrl_reset_7 [get_bd_pins c2c_link_ctrl/reset_7] [get_bd_pins link_7/reset]
        connect_bd_net -net gt_refclk_1 [get_bd_pins gt_refclk] [get_bd_pins link_0/gt_refclk] [get_bd_pins link_1/gt_refclk] [get_bd_pins link_2/gt_refclk] [get_bd_pins link_3/gt_refclk] [get_bd_pins link_4/gt_refclk] [get_bd_pins link_5/gt_refclk] [get_bd_pins link_6/gt_refclk] [get_bd_pins link_7/gt_refclk]
        connect_bd_net -net link_0_axi_c2c_config_error [get_bd_pins link_0/axi_c2c_config_error] [get_bd_pins xlconcat_config_error/In0]
        connect_bd_net -net link_0_axi_c2c_link_error [get_bd_pins link_0/axi_c2c_link_error] [get_bd_pins xlconcat_link_error/In0]
        connect_bd_net -net link_0_axi_c2c_link_status [get_bd_pins link_0/axi_c2c_link_status] [get_bd_pins xlconcat_link_status/In0]
        connect_bd_net -net link_0_axi_c2c_multi_bit_error [get_bd_pins link_0/axi_c2c_multi_bit_error] [get_bd_pins xlconcat_mbit_error/In0]
        connect_bd_net -net link_0_channel_up [get_bd_pins link_0/channel_up] [get_bd_pins xlconcat_channel_up/In0]
        connect_bd_net -net link_0_gt_pll_lock [get_bd_pins link_0/gt_pll_lock] [get_bd_pins xlconcat_gt_lock/In0]
        connect_bd_net -net link_0_hard_err [get_bd_pins link_0/hard_err] [get_bd_pins xlconcat_hard_err/In0]
        connect_bd_net -net link_1_axi_c2c_config_error [get_bd_pins link_1/axi_c2c_config_error] [get_bd_pins xlconcat_config_error/In1]
        connect_bd_net -net link_1_axi_c2c_link_error [get_bd_pins link_1/axi_c2c_link_error] [get_bd_pins xlconcat_link_error/In1]
        connect_bd_net -net link_1_axi_c2c_link_status [get_bd_pins link_1/axi_c2c_link_status] [get_bd_pins xlconcat_link_status/In1]
        connect_bd_net -net link_1_axi_c2c_multi_bit_error [get_bd_pins link_1/axi_c2c_multi_bit_error] [get_bd_pins xlconcat_mbit_error/In1]
        connect_bd_net -net link_1_channel_up [get_bd_pins link_1/channel_up] [get_bd_pins xlconcat_channel_up/In1]
        connect_bd_net -net link_1_gt_pll_lock [get_bd_pins link_1/gt_pll_lock] [get_bd_pins xlconcat_gt_lock/In1]
        connect_bd_net -net link_1_hard_err [get_bd_pins link_1/hard_err] [get_bd_pins xlconcat_hard_err/In1]
        connect_bd_net -net link_2_axi_c2c_config_error [get_bd_pins link_2/axi_c2c_config_error] [get_bd_pins xlconcat_config_error/In2]
        connect_bd_net -net link_2_axi_c2c_link_error [get_bd_pins link_2/axi_c2c_link_error] [get_bd_pins xlconcat_link_error/In2]
        connect_bd_net -net link_2_axi_c2c_link_status [get_bd_pins link_2/axi_c2c_link_status] [get_bd_pins xlconcat_link_status/In2]
        connect_bd_net -net link_2_axi_c2c_multi_bit_error [get_bd_pins link_2/axi_c2c_multi_bit_error] [get_bd_pins xlconcat_mbit_error/In2]
        connect_bd_net -net link_2_channel_up [get_bd_pins link_2/channel_up] [get_bd_pins xlconcat_channel_up/In2]
        connect_bd_net -net link_2_gt_pll_lock [get_bd_pins link_2/gt_pll_lock] [get_bd_pins xlconcat_gt_lock/In2]
        connect_bd_net -net link_2_hard_err [get_bd_pins link_2/hard_err] [get_bd_pins xlconcat_hard_err/In2]
        connect_bd_net -net link_3_axi_c2c_config_error [get_bd_pins link_3/axi_c2c_config_error] [get_bd_pins xlconcat_config_error/In3]
        connect_bd_net -net link_3_axi_c2c_link_error [get_bd_pins link_3/axi_c2c_link_error] [get_bd_pins xlconcat_link_error/In3]
        connect_bd_net -net link_3_axi_c2c_link_status [get_bd_pins link_3/axi_c2c_link_status] [get_bd_pins xlconcat_link_status/In3]
        connect_bd_net -net link_3_axi_c2c_multi_bit_error [get_bd_pins link_3/axi_c2c_multi_bit_error] [get_bd_pins xlconcat_mbit_error/In3]
        connect_bd_net -net link_3_channel_up [get_bd_pins link_3/channel_up] [get_bd_pins xlconcat_channel_up/In3]
        connect_bd_net -net link_3_gt_pll_lock [get_bd_pins link_3/gt_pll_lock] [get_bd_pins xlconcat_gt_lock/In3]
        connect_bd_net -net link_3_hard_err [get_bd_pins link_3/hard_err] [get_bd_pins xlconcat_hard_err/In3]
        connect_bd_net -net link_4_axi_c2c_config_error [get_bd_pins link_4/axi_c2c_config_error] [get_bd_pins xlconcat_config_error/In4]
        connect_bd_net -net link_4_axi_c2c_link_error [get_bd_pins link_4/axi_c2c_link_error] [get_bd_pins xlconcat_link_error/In4]
        connect_bd_net -net link_4_axi_c2c_link_status [get_bd_pins link_4/axi_c2c_link_status] [get_bd_pins xlconcat_link_status/In4]
        connect_bd_net -net link_4_axi_c2c_multi_bit_error [get_bd_pins link_4/axi_c2c_multi_bit_error] [get_bd_pins xlconcat_mbit_error/In4]
        connect_bd_net -net link_4_channel_up [get_bd_pins link_4/channel_up] [get_bd_pins xlconcat_channel_up/In4]
        connect_bd_net -net link_4_gt_pll_lock [get_bd_pins link_4/gt_pll_lock] [get_bd_pins xlconcat_gt_lock/In4]
        connect_bd_net -net link_4_hard_err [get_bd_pins link_4/hard_err] [get_bd_pins xlconcat_hard_err/In4]
        connect_bd_net -net link_5_axi_c2c_config_error [get_bd_pins link_5/axi_c2c_config_error] [get_bd_pins xlconcat_config_error/In5]
        connect_bd_net -net link_5_axi_c2c_link_error [get_bd_pins link_5/axi_c2c_link_error] [get_bd_pins xlconcat_link_error/In5]
        connect_bd_net -net link_5_axi_c2c_link_status [get_bd_pins link_5/axi_c2c_link_status] [get_bd_pins xlconcat_link_status/In5]
        connect_bd_net -net link_5_axi_c2c_multi_bit_error [get_bd_pins link_5/axi_c2c_multi_bit_error] [get_bd_pins xlconcat_mbit_error/In5]
        connect_bd_net -net link_5_channel_up [get_bd_pins link_5/channel_up] [get_bd_pins xlconcat_channel_up/In5]
        connect_bd_net -net link_5_gt_pll_lock [get_bd_pins link_5/gt_pll_lock] [get_bd_pins xlconcat_gt_lock/In5]
        connect_bd_net -net link_5_hard_err [get_bd_pins link_5/hard_err] [get_bd_pins xlconcat_hard_err/In5]
        connect_bd_net -net link_6_axi_c2c_config_error [get_bd_pins link_6/axi_c2c_config_error] [get_bd_pins xlconcat_config_error/In6]
        connect_bd_net -net link_6_axi_c2c_link_error [get_bd_pins link_6/axi_c2c_link_error] [get_bd_pins xlconcat_link_error/In6]
        connect_bd_net -net link_6_axi_c2c_link_status [get_bd_pins link_6/axi_c2c_link_status] [get_bd_pins xlconcat_link_status/In6]
        connect_bd_net -net link_6_axi_c2c_multi_bit_error [get_bd_pins link_6/axi_c2c_multi_bit_error] [get_bd_pins xlconcat_mbit_error/In6]
        connect_bd_net -net link_6_channel_up [get_bd_pins link_6/channel_up] [get_bd_pins xlconcat_channel_up/In6]
        connect_bd_net -net link_6_gt_pll_lock [get_bd_pins link_6/gt_pll_lock] [get_bd_pins xlconcat_gt_lock/In6]
        connect_bd_net -net link_6_hard_err [get_bd_pins link_6/hard_err] [get_bd_pins xlconcat_hard_err/In6]
        connect_bd_net -net link_7_axi_c2c_config_error [get_bd_pins link_7/axi_c2c_config_error] [get_bd_pins xlconcat_config_error/In7]
        connect_bd_net -net link_7_axi_c2c_link_error [get_bd_pins link_7/axi_c2c_link_error] [get_bd_pins xlconcat_link_error/In7]
        connect_bd_net -net link_7_axi_c2c_link_status [get_bd_pins link_7/axi_c2c_link_status] [get_bd_pins xlconcat_link_status/In7]
        connect_bd_net -net link_7_axi_c2c_multi_bit_error [get_bd_pins link_7/axi_c2c_multi_bit_error] [get_bd_pins xlconcat_mbit_error/In7]
        connect_bd_net -net link_7_channel_up [get_bd_pins link_7/channel_up] [get_bd_pins xlconcat_channel_up/In7]
        connect_bd_net -net link_7_gt_pll_lock [get_bd_pins link_7/gt_pll_lock] [get_bd_pins xlconcat_gt_lock/In7]
        connect_bd_net -net link_7_hard_err [get_bd_pins link_7/hard_err] [get_bd_pins xlconcat_hard_err/In7]
        connect_bd_net -net xlconcat_axi_config_error_dout [get_bd_pins c2c_link_ctrl/config_error] [get_bd_pins xlconcat_config_error/dout]
        connect_bd_net -net xlconcat_axi_link_status_dout [get_bd_pins c2c_link_ctrl/link_status] [get_bd_pins xlconcat_link_status/dout]
        connect_bd_net -net xlconcat_channel_up_dout [get_bd_pins c2c_link_ctrl/channel_up] [get_bd_pins xlconcat_channel_up/dout]
        connect_bd_net -net xlconcat_gt_lock_dout [get_bd_pins c2c_link_ctrl/gt_pll_lock] [get_bd_pins xlconcat_gt_lock/dout]
        connect_bd_net -net xlconcat_hard_err_dout [get_bd_pins c2c_link_ctrl/hard_err] [get_bd_pins xlconcat_hard_err/dout]
        connect_bd_net -net xlconcat_link_error_dout [get_bd_pins c2c_link_ctrl/link_error] [get_bd_pins xlconcat_link_error/dout]
        connect_bd_net -net xlconcat_mbit_error_dout [get_bd_pins c2c_link_ctrl/multi_bit_error] [get_bd_pins xlconcat_mbit_error/dout]

        # Restore current instance
        current_bd_instance $oldCurInst
    }
    # end of create chip2chip subsystem

    # Get object for parentCell
    set parentObj [get_bd_cells $parentCell]

    # Save current instance; Restore later
    set oldCurInst [current_bd_instance .]

    # Set parent object as current
    current_bd_instance $parentObj

    # ################################
    # Interfaces
    set aur_refclk_i [ create_bd_intf_port -mode Slave -vlnv xilinx.com:interface:diff_clock_rtl:1.0 aur_refclk_i ]
    set_property -dict [ list \
        CONFIG.FREQ_HZ {125000000} \
        ] $aur_refclk_i

    set aurora_rx_0 [ create_bd_intf_port -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 aurora_rx_0 ]

    set aurora_rx_1 [ create_bd_intf_port -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 aurora_rx_1 ]

    set aurora_rx_2 [ create_bd_intf_port -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 aurora_rx_2 ]

    set aurora_rx_3 [ create_bd_intf_port -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 aurora_rx_3 ]

    set aurora_rx_4 [ create_bd_intf_port -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 aurora_rx_4 ]

    set aurora_rx_5 [ create_bd_intf_port -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 aurora_rx_5 ]

    set aurora_rx_6 [ create_bd_intf_port -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 aurora_rx_6 ]

    set aurora_rx_7 [ create_bd_intf_port -mode Slave -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_RX_rtl:1.0 aurora_rx_7 ]

    set aurora_tx_0 [ create_bd_intf_port -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 aurora_tx_0 ]

    set aurora_tx_1 [ create_bd_intf_port -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 aurora_tx_1 ]

    set aurora_tx_2 [ create_bd_intf_port -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 aurora_tx_2 ]

    set aurora_tx_3 [ create_bd_intf_port -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 aurora_tx_3 ]

    set aurora_tx_4 [ create_bd_intf_port -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 aurora_tx_4 ]

    set aurora_tx_5 [ create_bd_intf_port -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 aurora_tx_5 ]

    set aurora_tx_6 [ create_bd_intf_port -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 aurora_tx_6 ]

    set aurora_tx_7 [ create_bd_intf_port -mode Master -vlnv xilinx.com:display_aurora:GT_Serial_Transceiver_Pins_TX_rtl:1.0 aurora_tx_7 ]

    set gtrefclk_in [ create_bd_intf_port -mode Slave -vlnv xilinx.com:interface:diff_clock_rtl:1.0 gtrefclk_in ]
    set_property -dict [ list \
        CONFIG.FREQ_HZ {125000000} \
    ] $gtrefclk_in

    set i2c_bckpl [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:iic_rtl:1.0 i2c_bckpl ]

    set i2c_emio [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:iic_rtl:1.0 i2c_emio ]

    set i2c_wrflash [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:iic_rtl:1.0 i2c_wrflash ]

    set sfp [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:sfp_rtl:1.0 sfp ]


    # Create ports
    set bckpl_rst_n_o [ create_bd_port -dir O bckpl_rst_n_o ]
    set bckpl_servmod_i [ create_bd_port -dir I -from 7 -to 0 bckpl_servmod_i ]
    set bckpl_servmod_o [ create_bd_port -dir O -from 7 -to 0 bckpl_servmod_o ]
    set bckpl_servmod_t [ create_bd_port -dir O -from 7 -to 0 bckpl_servmod_t ]
    set clk_src_sel_o [ create_bd_port -dir O -from 1 -to 0 clk_src_sel_o ]
    set f_rst_i [ create_bd_port -dir I f_rst_i ]
    set f_rst_o [ create_bd_port -dir O f_rst_o ]
    set f_rst_t [ create_bd_port -dir O f_rst_t ]
    set link_status_led [ create_bd_port -dir O link_status_led ]
    set link_sync_led [ create_bd_port -dir O link_sync_led ]
    set mdc_clk_led [ create_bd_port -dir O mdc_clk_led ]
    set p_pres_i_0 [ create_bd_port -dir I -from 1 -to 0 p_pres_i_0 ]
    set pl_reset_led [ create_bd_port -dir O -type rst pl_reset_led ]
    set psu_alert_i [ create_bd_port -dir I psu_alert_i ]
    set pwr_cycle_req_o_0 [ create_bd_port -dir O pwr_cycle_req_o_0 ]
    set tx_disable_o [ create_bd_port -dir O tx_disable_o ]

    # Create instance: aurora_refclk_buf, and set properties
    set aurora_refclk_buf [ create_bd_cell -type ip -vlnv xilinx.com:ip:util_ds_buf aurora_refclk_buf ]
    set_property -dict [ list \
        CONFIG.C_BUF_TYPE {IBUFDSGTE} \
        ] $aurora_refclk_buf

    # Create instance: axi_iic_0, and set properties
    set axi_iic_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_iic axi_iic_0 ]
    set_property -dict [ list \
        CONFIG.C_SCL_INERTIAL_DELAY {5} \
        CONFIG.C_SDA_INERTIAL_DELAY {5} \
        ] $axi_iic_0

    # Create instance: axi_iic_1, and set properties
    set axi_iic_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_iic axi_iic_1 ]
    set_property -dict [ list \
        CONFIG.C_SCL_INERTIAL_DELAY {5} \
        CONFIG.C_SDA_INERTIAL_DELAY {5} \
        CONFIG.IIC_FREQ_KHZ {100} \
        ] $axi_iic_1

    # Create instance: axi_protocol_convert_0, and set properties
    set axi_protocol_convert_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_protocol_converter axi_protocol_convert_0 ]

    # Create instance: chip2chip_subsystem
    create_hier_cell_chip2chip_subsystem [current_bd_instance .] chip2chip_subsystem

    # Create instance: fpd_axi_crossbar, and set properties
    set fpd_axi_crossbar [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_crossbar fpd_axi_crossbar ]
    set_property -dict [ list \
        CONFIG.ARUSER_WIDTH {0} \
        CONFIG.AWUSER_WIDTH {0} \
        CONFIG.CONNECTIVITY_MODE {SASD} \
        CONFIG.S01_BASE_ID {0x00010000} \
        CONFIG.S02_BASE_ID {0x00020000} \
        CONFIG.S03_BASE_ID {0x00030000} \
        CONFIG.S04_BASE_ID {0x00040000} \
        CONFIG.S05_BASE_ID {0x00050000} \
        CONFIG.S06_BASE_ID {0x00060000} \
        CONFIG.S07_BASE_ID {0x00070000} \
        CONFIG.S08_BASE_ID {0x00080000} \
        CONFIG.S09_BASE_ID {0x00090000} \
        CONFIG.S10_BASE_ID {0x000a0000} \
        CONFIG.S11_BASE_ID {0x000b0000} \
        CONFIG.S12_BASE_ID {0x000c0000} \
        CONFIG.S13_BASE_ID {0x000d0000} \
        CONFIG.S14_BASE_ID {0x000e0000} \
        CONFIG.S15_BASE_ID {0x000f0000} \
        CONFIG.STRATEGY {1} \
        ] $fpd_axi_crossbar

    # Create instance: fpga_dev, and set properties
    set block_name fpga_device
    set block_cell_name fpga_dev
    if { [catch {set fpga_dev [create_bd_cell -type module -reference $block_name $block_cell_name] } errmsg] } {
        catch {common::send_msg_id "BD_TCL-105" "ERROR" "Unable to add referenced block <$block_name>. Please add the files for ${block_name}'s definition into the project."}
        return 1
    } elseif { $fpga_dev eq "" } {
        catch {common::send_msg_id "BD_TCL-106" "ERROR" "Unable to referenced block <$block_name>. Please add the files for ${block_name}'s definition into the project."}
        return 1
    }

    # Create instance: gig_ethernet_pcs_pma_0, and set properties
    set gig_ethernet_pcs_pma_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:gig_ethernet_pcs_pma gig_ethernet_pcs_pma_0 ]
    set_property -dict [ list \
        CONFIG.Auto_Negotiation {true} \
        CONFIG.EMAC_IF_TEMAC {GEM} \
        CONFIG.Ext_Management_Interface {false} \
        CONFIG.GT_Location {X0Y3} \
        CONFIG.GTinEx {false} \
        CONFIG.LvdsRefClk {125} \
        CONFIG.Physical_Interface {Transceiver} \
        CONFIG.RefClkRate {125} \
        CONFIG.Standard {1000BASEX} \
        CONFIG.SupportLevel {Include_Shared_Logic_in_Core} \
        CONFIG.TransceiverControl {false} \
        ] $gig_ethernet_pcs_pma_0

    # Create instance: hpc0_axi_interconnect, and set properties
    set hpc0_axi_interconnect [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect hpc0_axi_interconnect ]
    set_property -dict [ list \
        CONFIG.NUM_MI {1} \
        CONFIG.NUM_SI {2} \
        ] $hpc0_axi_interconnect

    # Create instance: lpd_axi_interconnect, and set properties
    set lpd_axi_interconnect [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect lpd_axi_interconnect ]
    set_property -dict [ list \
        CONFIG.NUM_MI {3} \
        ] $lpd_axi_interconnect

    # Create instance: ps2pl_glue, and set properties
    set block_name ps2pl_glue
    set block_cell_name ps2pl_glue
    if { [catch {set ps2pl_glue [create_bd_cell -type module -reference $block_name $block_cell_name] } errmsg] } {
        catch {common::send_msg_id "BD_TCL-105" "ERROR" "Unable to add referenced block <$block_name>. Please add the files for ${block_name}'s definition into the project."}
        return 1
    } elseif { $ps2pl_glue eq "" } {
        catch {common::send_msg_id "BD_TCL-106" "ERROR" "Unable to referenced block <$block_name>. Please add the files for ${block_name}'s definition into the project."}
        return 1
    }

    # Create instance: psr_fpd, and set properties
    set psr_fpd [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset psr_fpd ]

    # Create instance: psr_lpd, and set properties
    set psr_lpd [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset psr_lpd ]

    source $target_path/tcl/ps_cfg.tcl

    # Create interface connections
    connect_bd_intf_net -intf_net CLK_IN_D_0_1 [get_bd_intf_ports aur_refclk_i] [get_bd_intf_pins aurora_refclk_buf/CLK_IN_D]
    connect_bd_intf_net -intf_net GT_RX_0_1 [get_bd_intf_ports aurora_rx_1] [get_bd_intf_pins chip2chip_subsystem/GT_RX_1]
    connect_bd_intf_net -intf_net GT_RX_1_1 [get_bd_intf_ports aurora_rx_2] [get_bd_intf_pins chip2chip_subsystem/GT_RX_2]
    connect_bd_intf_net -intf_net GT_RX_2_1 [get_bd_intf_ports aurora_rx_3] [get_bd_intf_pins chip2chip_subsystem/GT_RX_3]
    connect_bd_intf_net -intf_net GT_RX_3_1 [get_bd_intf_ports aurora_rx_4] [get_bd_intf_pins chip2chip_subsystem/GT_RX_4]
    connect_bd_intf_net -intf_net GT_RX_4_1 [get_bd_intf_ports aurora_rx_5] [get_bd_intf_pins chip2chip_subsystem/GT_RX_5]
    connect_bd_intf_net -intf_net GT_RX_5_1 [get_bd_intf_ports aurora_rx_6] [get_bd_intf_pins chip2chip_subsystem/GT_RX_6]
    connect_bd_intf_net -intf_net GT_RX_6_1 [get_bd_intf_ports aurora_rx_7] [get_bd_intf_pins chip2chip_subsystem/GT_RX_7]
    connect_bd_intf_net -intf_net GT_SERIAL_RX_0_1 [get_bd_intf_ports aurora_rx_0] [get_bd_intf_pins chip2chip_subsystem/GT_RX_0]
    connect_bd_intf_net -intf_net S00_AXI_1 [get_bd_intf_pins lpd_axi_interconnect/S00_AXI] [get_bd_intf_pins zynqmp_ps/M_AXI_HPM0_LPD]
    connect_bd_intf_net -intf_net aurora_dma_GT_SERIAL_TX_0 [get_bd_intf_ports aurora_tx_0] [get_bd_intf_pins chip2chip_subsystem/GT_TX_0]
    connect_bd_intf_net -intf_net aurora_dma_GT_TX_1 [get_bd_intf_ports aurora_tx_1] [get_bd_intf_pins chip2chip_subsystem/GT_TX_1]
    connect_bd_intf_net -intf_net aurora_dma_GT_TX_2 [get_bd_intf_ports aurora_tx_2] [get_bd_intf_pins chip2chip_subsystem/GT_TX_2]
    connect_bd_intf_net -intf_net aurora_dma_GT_TX_3 [get_bd_intf_ports aurora_tx_3] [get_bd_intf_pins chip2chip_subsystem/GT_TX_3]
    connect_bd_intf_net -intf_net aurora_dma_GT_TX_4 [get_bd_intf_ports aurora_tx_4] [get_bd_intf_pins chip2chip_subsystem/GT_TX_4]
    connect_bd_intf_net -intf_net aurora_dma_GT_TX_5 [get_bd_intf_ports aurora_tx_5] [get_bd_intf_pins chip2chip_subsystem/GT_TX_5]
    connect_bd_intf_net -intf_net aurora_dma_GT_TX_6 [get_bd_intf_ports aurora_tx_6] [get_bd_intf_pins chip2chip_subsystem/GT_TX_6]
    connect_bd_intf_net -intf_net aurora_dma_GT_TX_7 [get_bd_intf_ports aurora_tx_7] [get_bd_intf_pins chip2chip_subsystem/GT_TX_7]
    connect_bd_intf_net -intf_net aurora_dma_M_AXI [get_bd_intf_pins chip2chip_subsystem/M_AXI] [get_bd_intf_pins hpc0_axi_interconnect/S00_AXI]
    connect_bd_intf_net -intf_net aurora_dma_M_AXI_SG [get_bd_intf_pins chip2chip_subsystem/M_AXI_SG] [get_bd_intf_pins hpc0_axi_interconnect/S01_AXI]
    connect_bd_intf_net -intf_net axi_iic_0_IIC [get_bd_intf_ports i2c_wrflash] [get_bd_intf_pins axi_iic_0/IIC]
    connect_bd_intf_net -intf_net axi_iic_1_IIC [get_bd_intf_ports i2c_bckpl] [get_bd_intf_pins axi_iic_1/IIC]
    connect_bd_intf_net -intf_net axi_protocol_convert_0_M_AXI [get_bd_intf_pins axi_protocol_convert_0/M_AXI] [get_bd_intf_pins chip2chip_subsystem/S_AXI_CTRL]
    connect_bd_intf_net -intf_net fpd_axi_crossbar_M00_AXI [get_bd_intf_pins chip2chip_subsystem/S_AXI] [get_bd_intf_pins fpd_axi_crossbar/M00_AXI]
    connect_bd_intf_net -intf_net fpd_axi_crossbar_M01_AXI [get_bd_intf_pins axi_protocol_convert_0/S_AXI] [get_bd_intf_pins fpd_axi_crossbar/M01_AXI]
    connect_bd_intf_net -intf_net gig_ethernet_pcs_pma_0_sfp [get_bd_intf_ports sfp] [get_bd_intf_pins gig_ethernet_pcs_pma_0/sfp]
    connect_bd_intf_net -intf_net gtrefclk_in_1 [get_bd_intf_ports gtrefclk_in] [get_bd_intf_pins gig_ethernet_pcs_pma_0/gtrefclk_in]
    connect_bd_intf_net -intf_net hpc0_axi_interconnect_M00_AXI [get_bd_intf_pins hpc0_axi_interconnect/M00_AXI] [get_bd_intf_pins zynqmp_ps/S_AXI_HPC0_FPD]
    connect_bd_intf_net -intf_net lpd_axi_interconnect_M00_AXI [get_bd_intf_pins fpga_dev/S_AXI] [get_bd_intf_pins lpd_axi_interconnect/M00_AXI]
    connect_bd_intf_net -intf_net lpd_axi_interconnect_M01_AXI [get_bd_intf_pins axi_iic_0/S_AXI] [get_bd_intf_pins lpd_axi_interconnect/M01_AXI]
    connect_bd_intf_net -intf_net lpd_axi_interconnect_M02_AXI [get_bd_intf_pins axi_iic_1/S_AXI] [get_bd_intf_pins lpd_axi_interconnect/M02_AXI]
    connect_bd_intf_net -intf_net zynqmp_ps_GMII_ENET0 [get_bd_intf_pins gig_ethernet_pcs_pma_0/gmii_gem_pcs_pma] [get_bd_intf_pins zynqmp_ps/GMII_ENET0]
    connect_bd_intf_net -intf_net zynqmp_ps_IIC_1 [get_bd_intf_ports i2c_emio] [get_bd_intf_pins zynqmp_ps/IIC_1]
    connect_bd_intf_net -intf_net zynqmp_ps_MDIO_ENET0 [get_bd_intf_pins gig_ethernet_pcs_pma_0/mdio_pcs_pma] [get_bd_intf_pins zynqmp_ps/MDIO_ENET0]
    connect_bd_intf_net -intf_net zynqmp_ps_M_AXI_HPM1_FPD [get_bd_intf_pins fpd_axi_crossbar/S00_AXI] [get_bd_intf_pins zynqmp_ps/M_AXI_HPM1_FPD]

    # Create port connections
    connect_bd_net -net RST_PS_CLK0_interconnect_aresetn [get_bd_pins lpd_axi_interconnect/ARESETN] [get_bd_pins psr_lpd/interconnect_aresetn]
    connect_bd_net -net RST_PS_CLK0_peripheral_aresetn [get_bd_pins axi_iic_0/s_axi_aresetn] [get_bd_pins axi_iic_1/s_axi_aresetn] [get_bd_pins fpga_dev/S_AXI_ARESETN] [get_bd_pins lpd_axi_interconnect/M00_ARESETN] [get_bd_pins lpd_axi_interconnect/M01_ARESETN] [get_bd_pins lpd_axi_interconnect/M02_ARESETN] [get_bd_pins lpd_axi_interconnect/S00_ARESETN] [get_bd_pins psr_lpd/peripheral_aresetn]
    connect_bd_net -net aurora_dma_irq [get_bd_pins chip2chip_subsystem/irq] [get_bd_pins ps2pl_glue/aurora_dma_irq_i]
    connect_bd_net -net aurora_refclk_buf_IBUF_OUT [get_bd_pins aurora_refclk_buf/IBUF_OUT] [get_bd_pins chip2chip_subsystem/gt_refclk]
    connect_bd_net -net axi_iic_0_iic2intc_irpt [get_bd_pins axi_iic_0/iic2intc_irpt] [get_bd_pins ps2pl_glue/wrflash_i2c_irq_i]
    connect_bd_net -net axi_iic_1_iic2intc_irpt [get_bd_pins axi_iic_1/iic2intc_irpt] [get_bd_pins ps2pl_glue/bckpl_i2c_irq_i]
    connect_bd_net -net bckpl_servmod_i_1 [get_bd_ports bckpl_servmod_i] [get_bd_pins ps2pl_glue/bckpl_servmod_i]
    connect_bd_net -net f_rst_i_1 [get_bd_ports f_rst_i] [get_bd_pins ps2pl_glue/f_rst_i]
    connect_bd_net -net gig_ethernet_pcs_pma_0_status_vector [get_bd_pins gig_ethernet_pcs_pma_0/status_vector] [get_bd_pins ps2pl_glue/status_vector_i]
    connect_bd_net -net p_pres_i_0_1 [get_bd_ports p_pres_i_0] [get_bd_pins ps2pl_glue/p_pres_i]
    connect_bd_net -net pl_clk0 [get_bd_pins axi_iic_0/s_axi_aclk] [get_bd_pins axi_iic_1/s_axi_aclk] [get_bd_pins chip2chip_subsystem/aurora_init_clk] [get_bd_pins fpga_dev/S_AXI_ACLK] [get_bd_pins gig_ethernet_pcs_pma_0/independent_clock_bufg] [get_bd_pins lpd_axi_interconnect/ACLK] [get_bd_pins lpd_axi_interconnect/M00_ACLK] [get_bd_pins lpd_axi_interconnect/M01_ACLK] [get_bd_pins lpd_axi_interconnect/M02_ACLK] [get_bd_pins lpd_axi_interconnect/S00_ACLK] [get_bd_pins ps2pl_glue/pl_clk_i] [get_bd_pins psr_lpd/slowest_sync_clk] [get_bd_pins zynqmp_ps/maxihpm0_lpd_aclk] [get_bd_pins zynqmp_ps/pl_clk0]
    connect_bd_net -net pl_resetn0 [get_bd_ports pl_reset_led] [get_bd_pins ps2pl_glue/pl_resetn_i] [get_bd_pins psr_fpd/ext_reset_in] [get_bd_pins psr_lpd/ext_reset_in] [get_bd_pins zynqmp_ps/pl_resetn0]
    connect_bd_net -net ps2pl_glue_an_config_o [get_bd_pins gig_ethernet_pcs_pma_0/an_adv_config_val] [get_bd_pins gig_ethernet_pcs_pma_0/an_restart_config] [get_bd_pins ps2pl_glue/an_config_o]
    connect_bd_net -net ps2pl_glue_an_config_vec_o [get_bd_pins gig_ethernet_pcs_pma_0/an_adv_config_vector] [get_bd_pins ps2pl_glue/an_config_vec_o]
    connect_bd_net -net ps2pl_glue_bckpl_rst_n_o [get_bd_ports bckpl_rst_n_o] [get_bd_pins ps2pl_glue/bckpl_rst_n_o]
    connect_bd_net -net ps2pl_glue_bckpl_servmod_o [get_bd_ports bckpl_servmod_o] [get_bd_pins ps2pl_glue/bckpl_servmod_o]
    connect_bd_net -net ps2pl_glue_bckpl_servmod_t_o [get_bd_ports bckpl_servmod_t] [get_bd_pins ps2pl_glue/bckpl_servmod_t_o]
    connect_bd_net -net ps2pl_glue_clk_src_sel_o [get_bd_ports clk_src_sel_o] [get_bd_pins ps2pl_glue/clk_src_sel_o]
    connect_bd_net -net ps2pl_glue_configuration_valid_o [get_bd_pins gig_ethernet_pcs_pma_0/configuration_valid] [get_bd_pins ps2pl_glue/configuration_valid_o]
    connect_bd_net -net ps2pl_glue_configuration_vector_o [get_bd_pins gig_ethernet_pcs_pma_0/configuration_vector] [get_bd_pins ps2pl_glue/configuration_vector_o]
    connect_bd_net -net ps2pl_glue_f_rst_o [get_bd_ports f_rst_o] [get_bd_pins ps2pl_glue/f_rst_o]
    connect_bd_net -net ps2pl_glue_f_rst_t_o [get_bd_ports f_rst_t] [get_bd_pins ps2pl_glue/f_rst_t_o]
    connect_bd_net -net ps2pl_glue_link_status_led_o [get_bd_ports link_status_led] [get_bd_pins ps2pl_glue/link_status_led_o]
    connect_bd_net -net ps2pl_glue_link_sync_led_o [get_bd_ports link_sync_led] [get_bd_pins ps2pl_glue/link_sync_led_o]
    connect_bd_net -net ps2pl_glue_mdc_clk_led_o [get_bd_ports mdc_clk_led] [get_bd_pins ps2pl_glue/mdc_clk_led_o]
    connect_bd_net -net ps2pl_glue_phyaddr_o [get_bd_pins gig_ethernet_pcs_pma_0/phyaddr] [get_bd_pins ps2pl_glue/phyaddr_o]
    connect_bd_net -net ps2pl_glue_ps_emio_o [get_bd_pins ps2pl_glue/ps_emio_o] [get_bd_pins zynqmp_ps/emio_gpio_i]
    connect_bd_net -net ps2pl_glue_ps_irq_o [get_bd_pins ps2pl_glue/ps_irq_o] [get_bd_pins zynqmp_ps/pl_ps_irq0]
    connect_bd_net -net ps2pl_glue_pwr_cycle_req_o [get_bd_ports pwr_cycle_req_o_0] [get_bd_pins ps2pl_glue/pwr_cycle_req_o]
    connect_bd_net -net ps2pl_glue_reset_o [get_bd_pins gig_ethernet_pcs_pma_0/reset] [get_bd_pins ps2pl_glue/reset_o]
    connect_bd_net -net ps2pl_glue_signal_detect_o [get_bd_pins gig_ethernet_pcs_pma_0/signal_detect] [get_bd_pins ps2pl_glue/signal_detect_o]
    connect_bd_net -net ps2pl_glue_tx_disable_o [get_bd_ports tx_disable_o] [get_bd_pins ps2pl_glue/tx_disable_o]
    connect_bd_net -net psr_fpd_interconnect_aresetn [get_bd_pins axi_protocol_convert_0/aresetn] [get_bd_pins chip2chip_subsystem/s_aresetn] [get_bd_pins fpd_axi_crossbar/aresetn] [get_bd_pins hpc0_axi_interconnect/ARESETN] [get_bd_pins hpc0_axi_interconnect/M00_ARESETN] [get_bd_pins hpc0_axi_interconnect/S00_ARESETN] [get_bd_pins hpc0_axi_interconnect/S01_ARESETN] [get_bd_pins psr_fpd/interconnect_aresetn]
    connect_bd_net -net psu_alert_i_1 [get_bd_ports psu_alert_i] [get_bd_pins ps2pl_glue/psu_alert_i]
    connect_bd_net -net zynqmp_ps_emio_enet0_mdio_mdc [get_bd_pins gig_ethernet_pcs_pma_0/mdc] [get_bd_pins ps2pl_glue/mdc_i] [get_bd_pins zynqmp_ps/emio_enet0_mdio_mdc]
    connect_bd_net -net zynqmp_ps_emio_gpio_o [get_bd_pins ps2pl_glue/ps_emio_i] [get_bd_pins zynqmp_ps/emio_gpio_o]
    connect_bd_net -net zynqmp_ps_emio_gpio_t [get_bd_pins ps2pl_glue/ps_emio_t_i] [get_bd_pins zynqmp_ps/emio_gpio_t]
    connect_bd_net -net zynqmp_ps_pl_clk1 [get_bd_pins axi_protocol_convert_0/aclk] [get_bd_pins chip2chip_subsystem/s_aclk] [get_bd_pins fpd_axi_crossbar/aclk] [get_bd_pins hpc0_axi_interconnect/ACLK] [get_bd_pins hpc0_axi_interconnect/M00_ACLK] [get_bd_pins hpc0_axi_interconnect/S00_ACLK] [get_bd_pins hpc0_axi_interconnect/S01_ACLK] [get_bd_pins psr_fpd/slowest_sync_clk] [get_bd_pins zynqmp_ps/maxihpm1_fpd_aclk] [get_bd_pins zynqmp_ps/pl_clk1] [get_bd_pins zynqmp_ps/saxihpc0_fpd_aclk]

    # Create address segments
    assign_bd_address -offset 0x004800000000 -range 0x000100000000 -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs chip2chip_subsystem/link_0/axi_c2c/s_axi/Mem0] -force
    assign_bd_address -offset 0x004900000000 -range 0x000100000000 -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs chip2chip_subsystem/link_1/axi_c2c/s_axi/Mem0] -force
    assign_bd_address -offset 0x004A00000000 -range 0x000100000000 -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs chip2chip_subsystem/link_2/axi_c2c/s_axi/Mem0] -force
    assign_bd_address -offset 0x004B00000000 -range 0x000100000000 -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs chip2chip_subsystem/link_3/axi_c2c/s_axi/Mem0] -force
    assign_bd_address -offset 0x004C00000000 -range 0x000100000000 -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs chip2chip_subsystem/link_4/axi_c2c/s_axi/Mem0] -force
    assign_bd_address -offset 0x004D00000000 -range 0x000100000000 -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs chip2chip_subsystem/link_5/axi_c2c/s_axi/Mem0] -force
    assign_bd_address -offset 0x004E00000000 -range 0x000100000000 -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs chip2chip_subsystem/link_6/axi_c2c/s_axi/Mem0] -force
    assign_bd_address -offset 0x004F00000000 -range 0x000100000000 -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs chip2chip_subsystem/link_7/axi_c2c/s_axi/Mem0] -force
    assign_bd_address -offset 0xB0001000 -range 0x00001000 -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs chip2chip_subsystem/axi_cdma/S_AXI_LITE/Reg] -force
    assign_bd_address -offset 0x80001000 -range 0x00001000 -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs axi_iic_0/S_AXI/Reg] -force
    assign_bd_address -offset 0x80002000 -range 0x00001000 -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs axi_iic_1/S_AXI/Reg] -force
    assign_bd_address -offset 0xB0000000 -range 0x00001000 -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs chip2chip_subsystem/c2c_link_ctrl/s_axi/reg0] -force
    assign_bd_address -offset 0x80000000 -range 0x00001000 -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs fpga_dev/S_AXI/reg0] -force
    assign_bd_address -offset 0x004800000000 -range 0x000100000000 -target_address_space [get_bd_addr_spaces chip2chip_subsystem/axi_cdma/Data] [get_bd_addr_segs chip2chip_subsystem/link_0/axi_c2c/s_axi/Mem0] -force
    assign_bd_address -offset 0x004900000000 -range 0x000100000000 -target_address_space [get_bd_addr_spaces chip2chip_subsystem/axi_cdma/Data] [get_bd_addr_segs chip2chip_subsystem/link_1/axi_c2c/s_axi/Mem0] -force
    assign_bd_address -offset 0x004A00000000 -range 0x000100000000 -target_address_space [get_bd_addr_spaces chip2chip_subsystem/axi_cdma/Data] [get_bd_addr_segs chip2chip_subsystem/link_2/axi_c2c/s_axi/Mem0] -force
    assign_bd_address -offset 0x004B00000000 -range 0x000100000000 -target_address_space [get_bd_addr_spaces chip2chip_subsystem/axi_cdma/Data] [get_bd_addr_segs chip2chip_subsystem/link_3/axi_c2c/s_axi/Mem0] -force
    assign_bd_address -offset 0x004C00000000 -range 0x000100000000 -target_address_space [get_bd_addr_spaces chip2chip_subsystem/axi_cdma/Data] [get_bd_addr_segs chip2chip_subsystem/link_4/axi_c2c/s_axi/Mem0] -force
    assign_bd_address -offset 0x004D00000000 -range 0x000100000000 -target_address_space [get_bd_addr_spaces chip2chip_subsystem/axi_cdma/Data] [get_bd_addr_segs chip2chip_subsystem/link_5/axi_c2c/s_axi/Mem0] -force
    assign_bd_address -offset 0x004E00000000 -range 0x000100000000 -target_address_space [get_bd_addr_spaces chip2chip_subsystem/axi_cdma/Data] [get_bd_addr_segs chip2chip_subsystem/link_6/axi_c2c/s_axi/Mem0] -force
    assign_bd_address -offset 0x004F00000000 -range 0x000100000000 -target_address_space [get_bd_addr_spaces chip2chip_subsystem/axi_cdma/Data] [get_bd_addr_segs chip2chip_subsystem/link_7/axi_c2c/s_axi/Mem0] -force
    assign_bd_address -offset 0x000800000000 -range 0x000800000000 -target_address_space [get_bd_addr_spaces chip2chip_subsystem/axi_cdma/Data] [get_bd_addr_segs zynqmp_ps/SAXIGP0/HPC0_DDR_HIGH] -force
    assign_bd_address -offset 0x000800000000 -range 0x000800000000 -target_address_space [get_bd_addr_spaces chip2chip_subsystem/axi_cdma/Data_SG] [get_bd_addr_segs zynqmp_ps/SAXIGP0/HPC0_DDR_HIGH] -force
    assign_bd_address -offset 0xFFC00000 -range 0x00040000 -target_address_space [get_bd_addr_spaces chip2chip_subsystem/axi_cdma/Data] [get_bd_addr_segs zynqmp_ps/SAXIGP0/HPC0_LPS_OCM] -force
    assign_bd_address -offset 0xFFC00000 -range 0x00040000 -target_address_space [get_bd_addr_spaces chip2chip_subsystem/axi_cdma/Data_SG] [get_bd_addr_segs zynqmp_ps/SAXIGP0/HPC0_LPS_OCM] -force

    # Exclude Address Segments
    exclude_bd_addr_seg -offset 0x00000000 -range 0x80000000 -target_address_space [get_bd_addr_spaces chip2chip_subsystem/axi_cdma/Data] [get_bd_addr_segs zynqmp_ps/SAXIGP0/HPC0_DDR_LOW]
    exclude_bd_addr_seg -offset 0xC0000000 -range 0x20000000 -target_address_space [get_bd_addr_spaces chip2chip_subsystem/axi_cdma/Data] [get_bd_addr_segs zynqmp_ps/SAXIGP0/HPC0_QSPI]
    exclude_bd_addr_seg -target_address_space [get_bd_addr_spaces chip2chip_subsystem/axi_cdma/Data_SG] [get_bd_addr_segs zynqmp_ps/SAXIGP0/HPC0_DDR_LOW]
    exclude_bd_addr_seg -offset 0xC0000000 -range 0x20000000 -target_address_space [get_bd_addr_spaces chip2chip_subsystem/axi_cdma/Data_SG] [get_bd_addr_segs zynqmp_ps/SAXIGP0/HPC0_QSPI]
    exclude_bd_addr_seg -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs zynqmp_ps/SAXIGP0/HPC0_DDR_HIGH]
    exclude_bd_addr_seg -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs zynqmp_ps/SAXIGP0/HPC0_DDR_HIGH]
    exclude_bd_addr_seg -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs zynqmp_ps/SAXIGP0/HPC0_DDR_LOW]
    exclude_bd_addr_seg -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs zynqmp_ps/SAXIGP0/HPC0_DDR_LOW]
    exclude_bd_addr_seg -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs zynqmp_ps/SAXIGP0/HPC0_DDR_LOW]
    exclude_bd_addr_seg -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs zynqmp_ps/SAXIGP0/HPC0_DDR_LOW]
    exclude_bd_addr_seg -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs zynqmp_ps/SAXIGP0/HPC0_DDR_LOW]
    exclude_bd_addr_seg -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs zynqmp_ps/SAXIGP0/HPC0_LPS_OCM]
    exclude_bd_addr_seg -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs zynqmp_ps/SAXIGP0/HPC0_LPS_OCM]
    exclude_bd_addr_seg -target_address_space [get_bd_addr_spaces zynqmp_ps/Data] [get_bd_addr_segs zynqmp_ps/SAXIGP0/HPC0_QSPI]

    # Restore current instance
    current_bd_instance $oldCurInst

    validate_bd_design
    save_bd_design
    # fix for Chip2Chip bug, mentioned also in AR73018
    for {set i 0} {$i < 8} {incr i} {
        set_property CONFIG.C_INTERFACE_MODE 1 [get_bd_cells chip2chip_subsystem/link_$i/axi_c2c]
    }

    # Restore current instance
    current_bd_instance $oldCurInst

    validate_bd_design
    save_bd_design
    close_bd_design $block_design_name
}
